* This program reproduces tables and figures from the paper 
* "The Effects of Neighborhoods on Intergenerational Mobility: Childhood Exposure Effects and County Level Estimates".
* Part II: Causal Estimates by CZ and County

* The code is organized in 5 parts.
* The first part of the code produces the optimal predictions (section IX and online appendix table 1 and 2) at the CZ and County level. 
* The Second part of the code produces Figures from the paper.
* The Third part of the code produces Appendix Figures from the paper.
* The Fourht part of the code produces Tables from the paper.
* The Fifth part of the code produces Appendix Tables from the paper.


* PLEASE CHANGE THE DIRECTORY TO THE LOCATION OF THE REPLICATION FILES
global dir ../replicate
cd ${dir}
global data "${dir}/data"
global figures "${dir}/figures"
global tables "${dir}/tables"

* Install (update) maptile 
* For more informations on maptile, visit https://michaelstepner.com/maptile/
capture ssc install spmap
capture ssc install maptile
capture maptile_install using "http://files.michaelstepner.com/geo_county1990.zip"
capture maptile_install using "http://files.michaelstepner.com/geo_cz.zip"

* Install (update) binscatter
* For more information on binscatter, visit https://michaelstepner.com/binscatter/
capture ssc install binscatter 

************************* PART I - PREDICTED ESTIMATES *************************

* Create percentile to Dollar Conversion 

	global cz_pop_cutoff 25000
	use ${data}/Online_data_table3.dta if pop2000>=$cz_pop_cutoff, clear

	matrix C = J(5,13,.)
	local i = 1
	foreach p of numlist 25 75{
		matrix C[`i',1] = `p'
		qui reg perm_res_p`p'_kfi26 perm_res_p`p'_kr26 [w=pop2000]
		qui su perm_res_p`p'_kfi26 [w=pop2000]
		matrix C[`i',2] = r(mean)
		matrix C[`i',3] = 100*_b[perm_res_p`p'_kr26]/r(mean)
		qui reg perm_res_p`p'_kii26 perm_res_p`p'_kir26 [w=pop2000]
		qui su perm_res_p`p'_kii26 [w=pop2000]
		matrix C[`i',4] = r(mean)
		matrix C[`i',5] = 100*_b[perm_res_p`p'_kir26]/r(mean)
		qui reg perm_res_p`p'_kfi26_m perm_res_p`p'_kr26_m [w=pop2000]
		qui su perm_res_p`p'_kfi26_m [w=pop2000]
		matrix C[`i',6] = r(mean)
		matrix C[`i',7] = 100*_b[perm_res_p`p'_kr26_m]/r(mean)
		qui reg perm_res_p`p'_kfi26_f perm_res_p`p'_kr26_f [w=pop2000]
		qui su perm_res_p`p'_kfi26_f [w=pop2000]
		matrix C[`i',8] = r(mean)
		matrix C[`i',9] = 100*_b[perm_res_p`p'_kr26_f]/r(mean)
		qui reg perm_res_p`p'_kii26_m perm_res_p`p'_kir26_m [w=pop2000]
		qui su perm_res_p`p'_kii26_m [w=pop2000]
		matrix C[`i',10] = r(mean)
		matrix C[`i',11] = 100*_b[perm_res_p`p'_kir26_m]/r(mean)
		qui reg perm_res_p`p'_kii26_f perm_res_p`p'_kir26_f [w=pop2000]
		qui su perm_res_p`p'_kii26_f [w=pop2000]
		matrix C[`i',12] = r(mean)
		matrix C[`i',13] = 100*_b[perm_res_p`p'_kir26_f]/r(mean)
		local i = `i' + 1
	}
	svmat C
	list C* in 1/5
	keep C*
	keep if C1~=.

	rename C1 p
	rename C2 kr26_mean_inc
	rename C3 kr26_pctgain
	rename C4 kir26_mean_inc
	rename C5 kir26_pctgain
	rename C6 kr26_m_mean_inc
	rename C7 kr26_m_pctgain
	rename C8 kr26_f_mean_inc
	rename C9 kr26_f_pctgain
	rename C10 kir26_m_mean_inc
	rename C11 kir26_m_pctgain
	rename C12 kir26_f_mean_inc
	rename C13 kir26_f_pctgain
	
	gen kr26_dollargain = kr26_mean_inc*kr26_pctgain*(1/100)
	gen kir26_dollargain = kir26_mean_inc*kir26_pctgain*(1/100)
	gen kr26_m_dollargain = kr26_m_mean_inc*kr26_m_pctgain*(1/100)
	gen kr26_f_dollargain = kr26_f_mean_inc*kr26_f_pctgain*(1/100)
	gen kir26_m_dollargain = kir26_m_mean_inc*kir26_m_pctgain*(1/100)
	gen kir26_f_dollargain = kir26_f_mean_inc*kir26_f_pctgain*(1/100)
	
	save ${data}/percentile_dollar_conversion.dta, replace 

	foreach outcome in kr26 kr26_m kr26_f kir26 kir26_m kir26_f {
	foreach p in 25 75  {

	* Use Conversion File
	use ${data}/percentile_dollar_conversion.dta, clear
	
	* store Percentile Gain Conversion Factor 
	su  `outcome'_pctgain if p== `p'
	global pctgain_p`p'_`outcome' = r(mean)
	
	* Store Dollar Value Conversion Factor 
	su `outcome'_dollargain if p== `p'
	global dollargain_p`p'_`outcome' = r(mean)
	
	}
	}
	
	
* Predicted Estimates by Commuting Zone (Online Data table 1 with estimates in % mean income and in $)

	foreach outcome in kr26 kr26_m kr26_f kir26 kir26_m kir26_f km26 {
	foreach p in 25 75 {
	
	*Use Online Data Table 3
	use ${data}/Online_data_table3.dta, clear
	
	*Drop all observations with missing values of permanent residents, which are necessary for predictions
	keep if perm_res_p`p'_`outcome'~=.
	
	*Generate variances and precision weights
	if "`outcome'"=="kr26" | "`outcome'"=="kir26" {
	g causal_var_p`p'_cz`outcome'_bs = causal_p`p'_cz`outcome'_bs_se^2
	}
	else{ 
	g causal_var_p`p'_cz`outcome'_bs = causal_p`p'_cz`outcome'_se^2
	}
	g precwt = 1/causal_var_p`p'_cz`outcome'_bs
	
	* estimate noise variances 
	qui sum causal_var_p`p'_cz`outcome'_bs [w=precwt]
	global noisevar = r(mean)
	
	* estimate permanent residents predictions
	qui reg causal_p`p'_cz`outcome' perm_res_p`p'_`outcome' [w=precwt]
	global stayers_raw_coeff = _b[perm_res_p`p'_`outcome']
	global Rsq_stayers = e(r2)
	predict causal_pred, xb
	predict causal_resid, r
	
	*Predicted estimates using permanent residents predictions
	sum causal_resid [w=precwt]
	global resid_sigvar = r(sd)^2 - $noisevar
	di $resid_sigvar
	assert ${resid_sigvar}>0
	g shrinkage = $resid_sigvar/($resid_sigvar+causal_var_p`p'_cz`outcome'_bs)
	sum shrinkage [w=precwt],d
	g forecasts_p`p'_`outcome' = causal_pred + causal_resid*shrinkage if ${resid_sigvar}>0
	g forecasts_rmse_p`p'_`outcome' = sqrt(1/(1/${resid_sigvar}+1/causal_var_p`p'_cz`outcome'_bs))
	
	* Use predictions based purely on permanent residents for places with no estimates based on movers
	replace shrinkage = 0 if shrinkage==. & causal_pred~=. 
	replace forecasts_p`p'_`outcome' = causal_pred if shrinkage == 0
	replace forecasts_rmse_p`p'_`outcome' = sqrt(${resid_sigvar}) if shrinkage==0&causal_pred~=.

	if "`outcome'"=="km26"{
	keep cz czname state_id stateabbrv pop2000 forecasts* 

	}
	else{
	* Generate the causal impact in pct gain and in dollar gain terms
	gen dollar_effect_p`p'_`outcome' = forecasts_p`p'_`outcome' * ${dollargain_p`p'_`outcome'}	
	gen pct_causal_p`p'_`outcome' = forecasts_p`p'_`outcome' *${pctgain_p`p'_`outcome'}
	keep cz czname state_id stateabbrv pop2000 forecasts* pct_causal* dollar_effect*
	}
	tempfile forecasts_p`p'_`outcome'
	save `forecasts_p`p'_`outcome''
	}
	}
	
	
	* Merge outcomes  
	use `forecasts_p25_kr26'
	foreach outcome in kr26 kr26_m kr26_f kir26 kir26_m kir26_f km26 {
	foreach p in 25 75 {
	merge 1:1 cz using `forecasts_p`p'_`outcome'', nogen
	}
	}
	
	* generate gender average specification 
	foreach p in 25 75 {
	foreach outcome in kr26 kir26  {
	gen forecasts_p`p'_`outcome'_avg = 0.5*(forecasts_p`p'_`outcome'_f+forecasts_p`p'_`outcome'_m)
	gen forecasts_rmse_p`p'_`outcome'_avg = sqrt(forecasts_rmse_p`p'_`outcome'_f^2+forecasts_rmse_p`p'_`outcome'_m^2)/2
	gen dollar_effect_p`p'_`outcome'_avg = forecasts_p`p'_`outcome'_avg *${dollargain_p`p'_`outcome'}
	gen pct_causal_p`p'_`outcome'_avg = forecasts_p`p'_`outcome'_avg *${pctgain_p`p'_`outcome'}
	}
	}
	
	order cz czname state_id stateabbrv  *_p25_kr26 *_p75_kr26  *_p25_kr26_f *_p75_kr26_f *_p25_kr26_m  *_p75_kr26_m *_p25_kr26_avg *_p75_kr26_avg  *_p25_kir26  *_p75_kir26 *_p25_kir26_f  *_p75_kir26_f *_p25_kir26_m  *_p75_kir26_m *_p25_kir26_avg  *_p75_kir26_avg *_p25_km26  *_p75_km26 pop2000
	sort stateabbrv cz 
	
	save ${data}/Online_data_table1.dta, replace

	
* Predicted Estimates by County (Online Data table 2 with estimates in % mean income and in $)
	
	* Define Population cutoffs
	clear all
	macro drop cz_pop_cutoff cty_pop_cutoff
	global cz_pop_cutoff 25000
	global cty_pop_cutoff 10000
	
	foreach outcome in kr26 kr26_m kr26_f kir26 kir26_m kir26_f km26  {
	foreach p in 25 75 {

	*Use Online Data Table 4
	use ${data}/Online_data_table4.dta, clear
	
	* Merge with CZ level estimates from Online Data Table 3
	if "`outcome'" =="kr26" | "`outcome'" =="kir26" {
	merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p`p'_cz`outcome' causal_p`p'_cz`outcome'_bs_se) nogen
	}
	else{
	merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p`p'_cz`outcome' causal_p`p'_cz`outcome'_se) nogen
	gen causal_p`p'_cz`outcome'_bs_se = causal_p`p'_cz`outcome'_se
	}
	
	* compute CZ plus CTY estimates and variance
	g causal_p`p'_czct_`outcome'_bs_se = sqrt(causal_p`p'_cty_`outcome'_se^2+(causal_p`p'_cz`outcome'_bs_se^2))
	replace causal_p`p'_czct_`outcome'_bs_se = causal_p`p'_cz`outcome'_bs_se if causal_p`p'_czct_`outcome'_bs_se ==. & causal_p`p'_cz_cty_`outcome'~=.
	rename causal_p`p'_cz_cty_`outcome' causal_p`p'_czct_`outcome'
	
	*Drop all obs with missing values of permanent residents, which are necessary for predictions
	keep if perm_res_p`p'_`outcome'~=.
	
	*Generate variances and precision weights
	g causal_var_p`p'_czct`outcome'_bs = causal_p`p'_czct_`outcome'_bs_se ^2
	g precwt = 1/causal_var_p`p'_czct`outcome'_bs
	
	* estimate noise variances 
	qui sum causal_var_p`p'_czct`outcome'_bs [w=precwt]
	global noisevar = r(mean)
	
	* estimate permanent residents predictions
	qui reg causal_p`p'_czct_`outcome' perm_res_p`p'_`outcome' [w=precwt]
	global stayers_raw_coeff = _b[perm_res_p`p'_`outcome']
	global Rsq_stayers = e(r2)
	predict causal_pred, xb
	predict causal_resid, r
	
	*Predicted estimates using permanent residents predictions
	sum causal_resid [w=precwt]
	global resid_sigvar = r(sd)^2 - $noisevar
	di $resid_sigvar
	assert ${resid_sigvar}>0
	g shrinkage = $resid_sigvar/($resid_sigvar+causal_var_p`p'_czct`outcome'_bs)
	g forecasts_p`p'_`outcome' = causal_pred + causal_resid*shrinkage if ${resid_sigvar}>0
	g forecasts_rmse_p`p'_`outcome' = sqrt(1/(1/${resid_sigvar}+1/causal_var_p`p'_czct`outcome'_bs))
	
	* Use predictions based purely on permanent residents for places with no estimates based on movers
	replace shrinkage = 0 if shrinkage==. & causal_pred~=. 
	replace forecasts_p`p'_`outcome' = causal_pred if shrinkage == 0&causal_pred~=.
	replace forecasts_rmse_p`p'_`outcome'  = sqrt(${resid_sigvar}) if shrinkage==0&causal_pred~=.

	if "`outcome'"=="km26"{
	keep cty1990 cty2000 csa* county_name stateabbrv cty_pop2000 cz_pop2000 forecasts* 
	}
	else {
	* Generate the causal impact in pct gain and in dollar gain terms
	gen dollar_effect_p`p'_`outcome' = forecasts_p`p'_`outcome' * ${dollargain_p`p'_`outcome'}	
	gen pct_causal_p`p'_`outcome' = forecasts_p`p'_`outcome' *${pctgain_p`p'_`outcome'}
	keep cty1990 cty2000 csa* county_name stateabbrv cty_pop2000 cz_pop2000 forecasts* pct_causal* dollar_effect*
	}
	
	tempfile forecasts_p`p'_`outcome'
	save `forecasts_p`p'_`outcome''
	}
	}

	* Merge outcomes  
	use `forecasts_p25_kr26'
	foreach outcome in kr26 kr26_m kr26_f kir26 kir26_m kir26_f km26  {
	foreach p in 25 75 {
	merge 1:1 cty1990 cty2000 using `forecasts_p`p'_`outcome'', nogen
	}
	}
	
	* generate gender average specification 
	foreach p in 25 75 {
	foreach outcome in kr26 kir26  {
	gen forecasts_p`p'_`outcome'_avg = 0.5*(forecasts_p`p'_`outcome'_f+forecasts_p`p'_`outcome'_m)
	gen forecasts_rmse_p`p'_`outcome'_avg = sqrt(forecasts_rmse_p`p'_`outcome'_f^2+forecasts_rmse_p`p'_`outcome'_m^2)/2
	gen dollar_effect_p`p'_`outcome'_avg = forecasts_p`p'_`outcome'_avg *${dollargain_p`p'_`outcome'}
	gen pct_causal_p`p'_`outcome'_avg = forecasts_p`p'_`outcome'_avg *${pctgain_p`p'_`outcome'}
	}
	}
	
	save ${data}/Online_data_table2.dta, replace


***************************** PART II - FIGURES *****************************

* FIGURE 12 : The geography of Exposure Effects on Income Across CZs

	use ${data}/Online_data_table3.dta, clear
	keep cz causal_p25_czkr26 causal_p75_czkr26
	
	maptile causal_p25_czkr26, geo(cz) n(10) legdecimals(2) rev 
	graph export ${figures}/FigureXIIA.png, replace
	
	maptile causal_p75_czkr26, geo(cz) n(10) legdecimals(2) rev 
	graph export ${figures}/FigureXIIB.png, replace

	
* FIGURE 13 : Predicted Estimates: National CZ 
	
	use ${data}/Online_data_table1.dta, clear

	maptile forecasts_p25_kr26, geo(cz) n(10) legdecimals(2) rev 
	graph export ${figures}/FigureXIIIA.png, replace
	
	maptile forecasts_p75_kr26, geo(cz) n(10) legdecimals(2) rev 
	graph export ${figures}/FigureXIIIB.png, replace
	
	
* FIGURE 14 : Predicted Estimates for NY and Boston CSA by County

	* NY CSA
	use ${data}/Online_data_table2.dta, clear
	gen county=cty1990
	maptile forecasts_p25_kr26, geo(county1990) n(10) legdecimals(2) rev mapif(csa==408)
	graph export ${figures}/FigureXIVA.png, replace
	maptile forecasts_p75_kr26, geo(county1990) n(10) legdecimals(2) rev mapif(csa==408)
	graph export ${figures}/FigureXIVC.png, replace
	
	* Boston CSA
	use ${data}/Online_data_table2.dta, clear
	gen county=cty1990
	maptile forecasts_p25_kr26, geo(county1990) n(10) legdecimals(2) rev mapif(csa==148)
	graph export ${figures}/FigureXIVB.png, replace
	maptile forecasts_p75_kr26, geo(county1990) n(10) legdecimals(2) rev mapif(csa==148)
	graph export ${figures}/FigureXIVD.png, replace	

	
* FIGURE 15 : Predictors of Exposure Effects for Children With Parents at 25th Percentile 
	
	* define list of covariates
	global varlist ccd_pup_tch_ratio scap_ski90pcm cs_fam_wkidsinglemom gini ///
	cs_race_theil_2000 poor_share cs_race_bla
	
	* define scale factor (baseline is 20 years of exposure)
	global scale_factor =20
	
	*A. CZ level 
	
	* Use online data table 3
	use ${data}/Online_data_table3.dta, clear
	
	* define matrix to store results 
	mat define reg=J(7,2,.)
	local row =1
	matrix rownames reg= ${varlist}	
	
	*Drop all obs with missing values of permanent residents, which are necessary for decomposition into sorting and causal
	keep if perm_res_p25_kr26~=.
	
	* generate causal estimates (20 years of exposure)
	gen causal_20yrs_25 = ${scale_factor}*causal_p25_czkr26
	
	* Regressions with Observables
	foreach var of global varlist {
	
	qui reg perm_res_p25_kr26 `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',1] = _b[`var'_st]
	
	qui reg causal_20yrs_25 `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',2] = _b[`var'_st]

	local row = `row'+1
	}
	
	clear
	svmat2 reg, rnames(variables)
	gen number = [_n]
	rename reg1 perm_res_kr26_p25
	rename reg2 causal_kr26_p25
	order number variables
	
	g lower = min(causal_kr26_p25,perm_res_kr26_p25)
	g upper = max(causal_kr26_p25,perm_res_kr26_p25)
	drop number
	
	gen n = . 
	replace n = 1 if [_n]==1
	replace n = 2.5 if [_n]==2
	replace n = 4 if [_n]==3
	replace n = 5.5 if [_n]==4
	replace n = 7 if [_n]==5
	replace n = 8.5 if [_n]==6
	replace n = 10 if [_n]==7	


	twoway 	(bar causal_kr26_p25 n, barwidth(0.9) color(navy) horizontal xline(0, lcolor(gs3) lwidth(0.33))) ///
	(rcap lower upper n, lcolor(gs3) lpattern(dash) horizontal), ///
	xlabel(-2.5(0.5)2.5) ///
	ylabel(1 `""Student-" "Teacher" "Ratio""'  2.5 `" "Social" "Capital"  "' 4 `" "Fraction" "Single" "Moms" "' /// 
	5.5 `" "Gini" "Coef.""'   7 `" "Racial" "Segreg" "-ation" "' 8.5 `" "Poverty" "share" "' /// 
	10 `""Fraction" "Black" "Residents""', angle(horizontal)) ///
	xlabel(-2.5 "-2.5" -2.0 "-2.0" -1.5 "-1.5" -1 "-1.0" -0.5 "-0.5" 0 "0" 0.5 "0.5" 1.0 "1.0" 1.5 "1.5" 2.0 "2.0" 2.5 "2.5")  ///
	xtitle("Correlation") title(" ") ytitle(" ") legend(off) 
	graph export ${figures}/FigureXVA.png, replace	

* B. County level; within CZ

	* Use online data table 4
	use ${data}/Online_data_table4.dta, clear
	
	* define matrix to store results 
	mat define reg=J(7,2,.)
	local row =1
	matrix rownames reg= ${varlist}	
	
	*Drop all obs with missing values of permanent residents, which are necessary for decomposition into sorting and causal
	keep if perm_res_p25_kr26~=.
	
	* generate causal estimates (20 years of exposure)
	gen causal_20yrs_25 = ${scale_factor}*causal_p25_cty_kr26
	
	* Regressions with Observables
	foreach var of global varlist {
	
	qui areg perm_res_p25_kr26 `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
	mat def reg[`row',1] = _b[`var'_st]
	
	qui areg causal_20yrs_25 `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
	mat def reg[`row',2] = _b[`var'_st]

	local row = `row'+1
	}
	
	clear
	svmat2 reg, rnames(variables)
	gen number = [_n]
	rename reg1 perm_res_kr26_p25
	rename reg2 causal_kr26_p25
	order number variables
	
	g lower = min(causal_kr26_p25,perm_res_kr26_p25)
	g upper = max(causal_kr26_p25,perm_res_kr26_p25)
	drop number
	
	gen n = . 
	replace n = 1 if [_n]==1
	replace n = 2.5 if [_n]==2
	replace n = 4 if [_n]==3
	replace n = 5.5 if [_n]==4
	replace n = 7 if [_n]==5
	replace n = 8.5 if [_n]==6
	replace n = 10 if [_n]==7	


	twoway 	(bar causal_kr26_p25 n, barwidth(0.9) color(navy) horizontal xline(0, lcolor(gs3) lwidth(0.33))) ///
	(rcap lower upper n, lcolor(gs3) lpattern(dash) horizontal), ///
	xlabel(-2.5(0.5)2.5) ///
	ylabel(1 `""Student-" "Teacher" "Ratio""'  2.5 `" "Social" "Capital"  "' 4 `" "Fraction" "Single" "Moms" "' /// 
	5.5 `" "Gini" "Coef.""'   7 `" "Racial" "Segreg" "-ation" "' 8.5 `" "Poverty" "share" "' /// 
	10 `""Fraction" "Black" "Residents""', angle(horizontal)) ///
	xlabel(-2.5 "-2.5" -2.0 "-2.0" -1.5 "-1.5" -1 "-1.0" -0.5 "-0.5" 0 "0" 0.5 "0.5" 1.0 "1.0" 1.5 "1.5" 2.0 "2.0" 2.5 "2.5")  ///
	xtitle("Correlation") title(" ") ytitle(" ") legend(off) 
	graph export ${figures}/FigureXVB.png, replace


* FIGURE 16: Predictors of Exposure Effects for Children With Parents at 75th Percentile 

* define list of covariates
	global varlist ccd_pup_tch_ratio scap_ski90pcm cs_fam_wkidsinglemom gini ///
	cs_race_theil_2000 poor_share cs_race_bla
	
	* define scale factor (baseline is 20 years of exposure)
	global scale_factor =20
	
	*A. CZ level 
	
	* Use online data table 3
	use ${data}/Online_data_table3.dta, clear
	
	* define matrix to store results 
	mat define reg=J(7,2,.)
	local row =1
	matrix rownames reg= ${varlist}	
	
	*Drop all obs with missing values of permanent residents, which are necessary for decomposition into sorting and causal
	keep if perm_res_p75_kr26~=.
	
	* generate causal estimates (20 years of exposure)
	gen causal_20yrs_75 = ${scale_factor}*causal_p75_czkr26
	
	* Regressions with Observables
	foreach var of global varlist {
	
	qui reg perm_res_p75_kr26 `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',1] = _b[`var'_st]
	
	qui reg causal_20yrs_75 `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',2] = _b[`var'_st]

	local row = `row'+1
	}
	
	clear
	svmat2 reg, rnames(variables)
	gen number = [_n]
	rename reg1 perm_res_kr26_p75
	rename reg2 causal_kr26_p75
	order number variables
	
	g lower = min(causal_kr26_p75,perm_res_kr26_p75)
	g upper = max(causal_kr26_p75,perm_res_kr26_p75)
	drop number
	
	gen n = . 
	replace n = 1 if [_n]==1
	replace n = 2.5 if [_n]==2
	replace n = 4 if [_n]==3
	replace n = 5.5 if [_n]==4
	replace n = 7 if [_n]==5
	replace n = 8.5 if [_n]==6
	replace n = 10 if [_n]==7	


	twoway 	(bar causal_kr26_p75 n, barwidth(0.9) color(navy) horizontal xline(0, lcolor(gs3) lwidth(0.33))) ///
	(rcap lower upper n, lcolor(gs3) lpattern(dash) horizontal), ///
	xlabel(-2.5(0.5)2.5) ///
	ylabel(1 `""Student-" "Teacher" "Ratio""'  2.5 `" "Social" "Capital"  "' 4 `" "Fraction" "Single" "Moms" "' /// 
	5.5 `" "Gini" "Coef.""'   7 `" "Racial" "Segreg" "-ation" "' 8.5 `" "Poverty" "share" "' /// 
	10 `""Fraction" "Black" "Residents""', angle(horizontal)) ///
	xlabel(-2.5 "-2.5" -2.0 "-2.0" -1.5 "-1.5" -1 "-1.0" -0.5 "-0.5" 0 "0" 0.5 "0.5" 1.0 "1.0" 1.5 "1.5" 2.0 "2.0" 2.5 "2.5")  ///
	xtitle("Correlation") title(" ") ytitle(" ") legend(off) 
	graph export ${figures}/FigureXVIA.png, replace	

* B. County level; within CZ

	* Use online data table 4
	use ${data}/Online_data_table4.dta, clear
	
	* define matrix to store results 
	mat define reg=J(7,2,.)
	local row =1
	matrix rownames reg= ${varlist}	
	
	*Drop all obs with missing values of permanent residents, which are necessary for decomposition into sorting and causal
	keep if perm_res_p75_kr26~=.
	
	* generate causal estimates (20 years of exposure)
	gen causal_20yrs_75 = ${scale_factor}*causal_p75_cty_kr26
	
	* Regressions with Observables
	foreach var of global varlist {
	
	qui areg perm_res_p75_kr26 `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
	mat def reg[`row',1] = _b[`var'_st]
	
	qui areg causal_20yrs_75 `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
	mat def reg[`row',2] = _b[`var'_st]

	local row = `row'+1
	}
	
	clear
	svmat2 reg, rnames(variables)
	gen number = [_n]
	rename reg1 perm_res_kr26_p75
	rename reg2 causal_kr26_p75
	order number variables
	
	g lower = min(causal_kr26_p75,perm_res_kr26_p75)
	g upper = max(causal_kr26_p75,perm_res_kr26_p75)
	drop number
	
	gen n = . 
	replace n = 1 if [_n]==1
	replace n = 2.5 if [_n]==2
	replace n = 4 if [_n]==3
	replace n = 5.5 if [_n]==4
	replace n = 7 if [_n]==5
	replace n = 8.5 if [_n]==6
	replace n = 10 if [_n]==7	


	twoway 	(bar causal_kr26_p75 n, barwidth(0.9) color(navy) horizontal xline(0, lcolor(gs3) lwidth(0.33))) ///
	(rcap lower upper n, lcolor(gs3) lpattern(dash) horizontal), ///
	xlabel(-2.5(0.5)2.5) ///
	ylabel(1 `""Student-" "Teacher" "Ratio""'  2.5 `" "Social" "Capital"  "' 4 `" "Fraction" "Single" "Moms" "' /// 
	5.5 `" "Gini" "Coef.""'   7 `" "Racial" "Segreg" "-ation" "' 8.5 `" "Poverty" "share" "' /// 
	10 `""Fraction" "Black" "Residents""', angle(horizontal)) ///
	xlabel(-2.5 "-2.5" -2.0 "-2.0" -1.5 "-1.5" -1 "-1.0" -0.5 "-0.5" 0 "0" 0.5 "0.5" 1.0 "1.0" 1.5 "1.5" 2.0 "2.0" 2.5 "2.5")  ///
	xtitle("Correlation") title(" ") ytitle(" ") legend(off) 
	graph export ${figures}/FigureXVIB.png, replace
	
	
* FIGURE 17: Median Rent versus Exposure Effects 

* Generate Predicted estimates without using any covariates

	* Define Segregation Variable and Population Cutoff
	global cutvar frac_traveltime_lt15
	global cz_cut = 1e6
	
	*Use Online Data Table 4
	use ${data}/Online_data_table4.dta, clear
	
	* Merge with CZ level estimates from Online Data Table 3
	merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p25_czkr26 causal_p25_czkr26_bs_se) nogen

	* compute CZ plus CTY estimates and variance
	g causal_p25_czct_kr26_bs_se = sqrt(causal_p25_cty_kr26_se^2+(causal_p25_czkr26_bs_se^2))
	replace causal_p25_czct_kr26_bs_se = causal_p25_czkr26_bs_se if causal_p25_czct_kr26_bs_se ==. & causal_p25_cz_cty_kr26~=.
	rename causal_p25_cz_cty_kr26 causal_p25_czct_kr26
	
	*Generate variances and precision weights
	g causal_var_p25_czctkr26_bs = causal_p25_czct_kr26_bs_se ^2
	g precwt = 1/causal_var_p25_czctkr26_bs
	
	* estimate total variance 
	qui sum causal_p25_czct_kr26 [w=precwt],d
	global totvar = r(Var)
	
	* estimate noise variance 
	qui sum causal_var_p25_czctkr26_bs [w=precwt]
	global noisevar = r(mean)
	
	global sigvar = $totvar-$noisevar
	assert ${sigvar}>0

	* predicted(RMSE-minimizing) estimates without using any covariates
	g shrinkage_raw = $sigvar/($sigvar+causal_var_p25_czctkr26_bs)
	g forecasts_raw_p25_kr26 = shrinkage_raw*causal_p25_czct_kr26
	
	* split into high and low segregation
	preserve 
	collapse (mean) ${cutvar} cz_pop2000 [w=cty_pop] if cz_pop2000 > ${cz_cut}  , by(cz)
	su ${cutvar} if cz_pop2000 > ${cz_cut} , d
	g seg_cz = ${cutvar} < r(p50) 
	keep cz seg_cz
	tempfile temp
	save `temp' , replace
	restore
	merge m:1 cz using `temp' , nogen
	
*A. Median Segregated CZs with Population above 100,000
	
	areg median_rent forecasts_raw_p25_kr26 [w=cty_pop] if cz_pop2000 > ${cz_cut} & seg_cz == 1 , absorb(cz)
	qui local slope = string(_b[forecasts_raw_p25_kr26], "%4.3f")
	qui local se =  string(_se[forecasts_raw_p25_kr26], "%4.3f")
	
	binscatter median_rent forecasts_raw_p25_kr26 [w=cty_pop] if cz_pop2000 > ${cz_cut} & seg_cz == 1 , absorb(cz) ///
	title(" ") xtitle("Predicted Estimates") ytitle("Median Rent") ///
	yscale(range(700(50)1000)) ylabel(700(50)1000) ///
	 text(775 0.15 "Slope: `slope'" "(`se')") 
	 graph export "${figures}/FigureXVIIA.png", replace

	 
* B. Non Segregated Commuting Zones
	 
	areg median_rent forecasts_raw_p25_kr26 [w=cty_pop] if cz_pop2000 > ${cz_cut} & seg_cz == 0 , absorb(cz)
	qui local slope = string(_b[forecasts_raw_p25_kr26], "%4.3f")
	qui local se =  string(_se[forecasts_raw_p25_kr26], "%4.3f")
	
	binscatter median_rent forecasts_raw_p25_kr26 [w=cty_pop] if cz_pop2000 > ${cz_cut} & seg_cz == 0 , absorb(cz) ///
	title(" ") xtitle("Predicted Estimates") ytitle("Median Rent") ///
	yscale(range(500(50)800)) ylabel(500(50)800) ///
	 text(775 0.15 "Slope: `slope'" "(`se')") 
	 graph export "${figures}/FigureXVIIB.png", replace

* C. Rural Areas  

	areg median_rent forecasts_raw_p25_kr26 [w=cty_pop] if cz_pop2000 < ${cz_cut} , absorb(cz)
	qui local slope = string(_b[forecasts_raw_p25_kr26], "%4.3f")
	qui local se =  string(_se[forecasts_raw_p25_kr26], "%4.3f")
	
	binscatter median_rent forecasts_raw_p25_kr26 [w=cty_pop] if cz_pop2000 < ${cz_cut}, absorb(cz) ///
	title(" ") xtitle("Predicted Estimates") ytitle("Median Rent") ///
	ylabel(350(50)650) yscale(range(350(50)650)) ///
	 text(425 0.075 "Slope: `slope'" "(`se')") 
	graph export "${figures}/FigureXVIIC.png", replace

	
* FIGURE 18: Median Rent versus Unobservable and Observable Exposure Effects

	* Define observable characteristics and population cutoff
	local obs cs_fam_wkidsinglemom_st frac_traveltime_lt15_st gini99_st poor_share_st score_r_st
	global cz_cut = 1e6
	
	*Use Online Data Table 4
	use ${data}/Online_data_table4.dta, clear
	
	* Keep relevant variables only
	keep cty1990 cty2000 *pop* causal_p25_cty_kr26_se causal_p25_cty_kr26 median_rent `obs'

	*Generate variances and precision weights
	g causal_var_p25_cty_kr26 = causal_p25_cty_kr26_se ^2
	g precwt = 1/causal_var_p25_cty_kr26
	
	* estimate total variance 
	areg causal_p25_cty_kr26 [w=precwt] if cz_pop >${cz_cut} , a(cz)
	global totvar = e(rmse)^2
	
	* estimate noise variance 
	qui sum causal_var_p25_cty_kr26 [w=precwt] if cz_pop >${cz_cut}
	global noisevar = r(mean)
	
	* Construct observable portion of raw values
	areg causal_p25_cty_kr26 `obs' [w=precwt] if cz_pop > ${cz_cut}  , a(cz)
	predict causal_obs if cz_pop > ${cz_cut} & e(sample), xb
	predict causal_res if cz_pop > ${cz_cut} & e(sample), r

	areg causal_obs [w=precwt] if cz_pop > ${cz_cut}, a(cz)
	global obs_var = e(rmse)^2
	
	global resid_var = ${totvar} - ${obs_var} - ${noisevar}

	gen shrinkage = ${resid_var}/(${resid_var}+causal_var_p25_cty_kr26)
	gen residual_forecasts_p25_kr26 = shrinkage*causal_res

	 * A. Observable Component
	
	qui areg  median_rent causal_obs residual_forecasts_p25_kr26 if cz_pop > ${cz_cut}  [w=cty_pop2000], a(cz)
	qui local slope = string(_b[causal_obs], "%4.3f")
	qui local se =  string(_se[causal_obs], "%4.3f")
	
	binscatter median_rent causal_obs if cz_pop > ${cz_cut}  [w=cty_pop2000] , controls(residual_forecasts_p25_kr26) absorb(cz) n(20) ///
	title(" ") xtitle("Observed Place Effect (Forecast Regressed on Observables)") ytitle("Median Rent") ///
	ylabel(650(50)950) yscale(range(650(50)950)) ///
	 text(725 0.075 "Slope: `slope'" "(`se')") 
	graph export "${figures}/FigureXVIIIA.png", replace
	
	* B. Unobservable Component
	
	qui areg  median_rent residual_forecasts_p25_kr26 causal_obs if cz_pop > ${cz_cut}  [w=cty_pop2000], a(cz)
	qui local slope = string(_b[residual_forecasts_p25_kr26], "%4.3f")
	qui local se =  string(_se[residual_forecasts_p25_kr26], "%4.3f")
	
	binscatter median_rent residual_forecasts_p25_kr26 if cz_pop > ${cz_cut}  [w=cty_pop2000], controls(causal_obs) absorb(cz) n(20) ///
	title(" ") xtitle("Unobserved Place Effect (Residual from Forecast Regressed on Observables)") ytitle("Median Rent") ///
	ylabel(650(50)950) yscale(range(650(50)950)) ///
	 text(725 0.075 "Slope: `slope'" "(`se')") 
	graph export "${figures}/FigureXVIIIB.png", replace
	
	
************************* PART III - APPENDIX FIGURES *************************

	
* ONLINE APPENDIX FIGURE 7 : Correlations of Place Effects by age (p25)

	global namelist age20 age21 age22 age23 age24 age25 age26 age27 age28 age29 age30 age31 age32

	* Define Matrix
	mat define corr=J(13,1,.)
	matrix rownames corr= ${namelist}
	
	local row = 1
	forvalues age = 20(1)32 {
	
	* use beta dataset
	use ${data}/Online_data_table3.dta, clear
	
	*Drop all obs with missing values of stayers, which are necessary for predictions
	keep if perm_res_p25_kr`age'~=.
	
	* Correlations with Observables
	corr perm_res_p25_kr`age' perm_res_p25_kr32 [w=pop2000]
	
	mat def corr[`row',1] = r(rho)
	local row = `row'+1
	}	
	
	* store results in the corrspec matrix
	clear
	svmat2 corr, rnames(variables)
	gen age = [_n] + 19
	rename corr1 corr
	twoway scatter corr age,  ///
	ylabel(0 "0" 0.2 "0.2" 0.4 "0.4" 0.6 "0.6" 0.8 "0.8" 1.0 "1.0") xlabel(20(2)32) legend(off) ytitle("Correlation with Age 32 Measurement") xtitle("Age of Income Measurement") ///
	title(" ") 
	graph export ${figures}/AppendixFigureVII.png, replace
	
	
* APPENDIX FIGURE 8: distribution of Predicted Values by Gender
	
	* Use predicted values data 	
	use ${data}/Online_data_table2.dta, clear
	
	* Cumulative Density Function: Male 
	sort forecasts_p25_kr26_m 
	gen cum_pop_m = sum(cty_pop2000)
	egen total_pop_m = total(cty_pop2000)
	gen cum_pop_0_1_m = cum_pop_m/total_pop_m
	gen gdr = "male"

	tempfile male 
	save `male'
	
	* Cumulative Density Function: Female 
	use ${data}/Online_data_table2.dta, clear
	sort forecasts_p25_kr26_f 
	gen cum_pop_f = sum(cty_pop2000)
	egen total_pop_f = total(cty_pop2000)
	gen cum_pop_0_1_f = cum_pop_f/total_pop_f
	gen gdr= "female"

	append using `male'
	
	twoway (line cum_pop_0_1_m forecasts_p25_kr26_m if (gdr=="male"&forecasts_p25_kr26_m>=-0.4 & forecasts_p25_kr26_m<=0.4) , lwidth(medthick) lcolor(navy)) ///
	(line cum_pop_0_1_f forecasts_p25_kr26_f if (gdr=="female"&forecasts_p25_kr26_f>=-0.4 & forecasts_p25_kr26_f<=0.4) ,  lwidth(medthick)lpattern(dash) lcolor(maroon)), ///
	xscale(range(-0.4 0.4)) ///
	title(" ") xtitle("Predicted Estimates") ytitle("Cumulative Distribution") legend(off)
	
	graph export "${figures}/AppendixFigureVIII.png", replace

	
* ONLINE APPENDIX FIGURE 9 : Predicted Estimates: National CZ using Individual Incomes

	use ${data}/Online_data_table1.dta, clear
	maptile forecasts_p25_kir26, geo(cz) n(10) legdecimals(2) rev 
	graph export ${figures}/AppendixFigureIXA.png, replace
	
	use ${data}/Online_data_table1.dta, clear
	maptile forecasts_p75_kir26, geo(cz) n(10) legdecimals(2) rev 
	graph export ${figures}/AppendixFigureIXB.png, replace
	
* ONLINE APPENDIX FIGURE 10 : Predicted Estimates: National CZ - Male and Female

	use ${data}/Online_data_table1.dta, clear
	maptile forecasts_p25_kr26_m, geo(cz) n(10) legdecimals(2) rev 
	graph export ${figures}/AppendixFigureXA.png, replace
	
	use ${data}/Online_data_table1.dta, clear
	maptile forecasts_p25_kr26_f, geo(cz) n(10) legdecimals(2) rev 
	graph export ${figures}/AppendixFigureXB.png, replace
	
* ONLINE APPENDIX FIGURE 11 : Predicted Estimates: National CZ - Male and Female - Using Individual Incomes

	use ${data}/Online_data_table1.dta, clear
	maptile forecasts_p25_kir26_m, geo(cz) n(10) legdecimals(2) rev 
	graph export ${figures}/AppendixFigureXIA.png, replace
	
	use ${data}/Online_data_table1.dta, clear
	maptile forecasts_p25_kir26_f, geo(cz) n(10) legdecimals(2) rev 
	graph export ${figures}/AppendixFigureXIB.png, replace

	
	
******************************* PART IV - TABLES *******************************


* TABLE 7 : Model Variance Components : Causal and Selection Effects

	* Define variance components
	global namelist Raw_Exposure_Effect_(SD) Noise_(SD) Signal_of_Exposure_Effects_(SD) ///
	Signal_to_Noise_Ratio Correlation_p25_p75  ///
	Causal_Effect_(SD_of_Signal) Permanent_Residents_(SD) ///
	Sorting_Component_(SD) Corr_Sorting_Causal
	
	* Define scale Factor
	global scale_factor 20
		
	* A commuting Zone Level 

		foreach p in 25 75 {
		
		* Use CZ level dataset
		use ${data}/Online_data_table3.dta, clear
		
		* Define matrix to store the results
		mat define czvar_p`p'=J(9,1,.)
		matrix rownames czvar_p`p'= ${namelist}
	
		*Drop all obs with missing values of stayers, which are necessary for predictions
		keep if perm_res_p`p'_kr26~=.
	 
		*Generate variances and precision weights
		g causal_var_p`p'_czkr26_bs = causal_p`p'_czkr26_bs_se^2
		g precwt = 1/causal_var_p`p'_czkr26_bs	
		
		* estimate signal and noise variances 
		qui sum causal_var_p`p'_czkr26_bs [w=precwt]
		global noisevar = r(mean)
		
		qui sum causal_p`p'_czkr26 [w=precwt],d
		global totvar = r(Var)
		
		global sigvar = $totvar-$noisevar
		assert ${sigvar}>0
		global sigsd = sqrt($sigvar)
	
		*Estimates of causal and sorting effects
		g causal_p`p' = ${scale_factor}*causal_p`p'_czkr26
		g sorting_p`p' = perm_res_p`p'_kr26-causal_p`p'
		
		*Variance decomposition
		qui sum perm_res_p`p'_kr26 [w=precwt]
		global stayers_var = r(Var)
		
		*Signal variance of causal effects
		global causal_var = (${scale_factor}*${sigsd})^2
		
		*Covariance of causal effects and sorting
		reg causal_p`p' perm_res_p`p'_kr26 [w=precwt]
		global covar_causal_sorting = _b[perm_res_p`p'_kr26]*${stayers_var}-${causal_var}
		global sorting_var = ${stayers_var}-${causal_var}-2*${covar_causal_sorting}
	
		* store the results
		mat def czvar_p`p'[1,1] = sqrt(${totvar})
		mat def czvar_p`p'[2,1] = sqrt(${noisevar})
		mat def czvar_p`p'[3,1] = sqrt(${sigvar})
		mat def czvar_p`p'[4,1] = ${sigvar}/$noisevar
		
		mat def czvar_p`p'[6,1] = sqrt(${causal_var})
		mat def czvar_p`p'[7,1] = sqrt(${stayers_var})
		mat def czvar_p`p'[8,1] = sqrt($sorting_var)
		mat def czvar_p`p'[9,1] = ${covar_causal_sorting}/(sqrt(${sorting_var})*sqrt(${causal_var}))	
	
		* Correlations 
		g v25 = causal_p25_czkr26_bm_se^2 
		g prec25 = 1/v25
		g v75 = causal_p75_czkr26_am_se^2 
		g prec75 = 1/v75
		g weight = 1/(v25 + v75)

		corr causal_p25_czkr26_bm causal_p75_czkr26_am [w=weight]  , cov
		global cov = r(cov_12)

		su v25 [w=prec25]
		global noise25 = r(mean)
		su causal_p25_czkr26_bm [w=prec25]
		global totvar25 = r(Var)
		global sd25 = sqrt($totvar25 - $noise25)

		su v75 [w=prec75]
		global noise75 = r(mean)
		su causal_p75_czkr26_am [w=prec75]
		global totvar75 = r(Var)
		global sd75 = sqrt($totvar75 - $noise75)

		global corr_cz = $cov / ($sd25 * $sd75)

		* store the correlation in the czreg matrix
		mat def czvar_p`p'[5,1] = $corr_cz
			
		* store results in the czvar matrix
		clear
		svmat2 czvar_p`p', rnames(variables)
		gen number = [_n]
		rename czvar_p`p'1 cz_se_kr26_p`p'
		order number variables 
		tempfile czvar_kr26_p`p'
		save `czvar_kr26_p`p''
		}
		
		* organizing the commuting zones part:
		use `czvar_kr26_p25', clear
		merge 1:1 number using `czvar_kr26_p75', nogen
		tempfile czvar_full
		sa `czvar_full'
	
	* B County Level 

	* Population Restrictions
	macro drop cz_pop_cutoff cty_pop_cutoff
	global cz_pop_cutoff 25000
	global cty_pop_cutoff 10000
	
		foreach p in 25 75 {
		
		* Define matrix to store the results
		mat define ctyvar_p`p'=J(9,1,.)
		matrix rownames ctyvar_p`p'= ${namelist}
		
		* Use County level dataset
		use ${data}/Online_data_table4.dta, clear
		bys cz: gen cty_by_cz = _N

		* Merge with CZ level estimates from Online Data Table 3
		merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p*_czkr26 causal_p*_czkr26_am causal_p*_czkr26_bm causal_p*_czkr26_bs_se causal_p*_czkr26_am_se causal_p*_czkr26_bm_se) nogen

		* compute CZ plus CTY estimates and variance
		g causal_p`p'_czct_kr26_bs_se = sqrt(causal_p`p'_cty_kr26_se^2+(causal_p`p'_czkr26_bs_se^2))
		replace causal_p`p'_czct_kr26_bs_se = causal_p`p'_czkr26_bs_se if causal_p`p'_czct_kr26_bs_se ==. & causal_p`p'_cz_cty_kr26~=.
		rename causal_p`p'_cz_cty_kr26 causal_p`p'_czct_kr26
	
		*Drop all obs with missing values of permanent residents, which are necessary for predictions
		keep if perm_res_p`p'_kr26~=.
		
		*Generate variances and precision weights
		g causal_var_p`p'_czctkr26_bs = causal_p`p'_czct_kr26_bs_se ^2
		g precwt = 1/causal_var_p`p'_czctkr26_bs
		
		* estimate noise variances 
		qui sum causal_var_p`p'_czctkr26_bs [w=precwt]
		global noisevar = r(mean)
		
		*Calculate total variance
		su causal_p`p'_czct_kr26 [w=precwt], d
		global totvar=r(Var)

		global sigvar = $totvar-$noisevar
		assert ${sigvar}>0
		global sigsd = sqrt($sigvar)
			
		*Estimates of causal and sorting effects
		g causal_p`p' = ${scale_factor}*causal_p`p'_czct_kr26
		g sorting_p`p' = perm_res_p`p'_kr26-causal_p`p'
		
		*Variance decomposition
		sum perm_res_p`p'_kr26 [w=precwt]
		global stayers_var = r(Var)
		
		*Signal variance of causal effects
		global causal_var = (${scale_factor}*${sigsd})^2	
		
		*Covariance of causal effects and sorting
		reg causal_p`p' perm_res_p`p'_kr26 [w=precwt]
		global covar_causal_sorting = _b[perm_res_p`p'_kr26]*${stayers_var}-${causal_var}
		global sorting_var = ${stayers_var}-${causal_var}-2*${covar_causal_sorting}

		* store the results
		mat def ctyvar_p`p'[1,1] = sqrt(${totvar})
		mat def ctyvar_p`p'[2,1] = sqrt(${noisevar})
		mat def ctyvar_p`p'[3,1] = sqrt(${sigvar})
		mat def ctyvar_p`p'[4,1] = ${sigvar}/$noisevar
		
		mat def ctyvar_p`p'[6,1] = sqrt(${causal_var})
		mat def ctyvar_p`p'[7,1] = sqrt(${stayers_var})
		mat def ctyvar_p`p'[8,1] = sqrt($sorting_var)
		mat def ctyvar_p`p'[9,1] = ${covar_causal_sorting}/(sqrt(${sorting_var})*sqrt(${causal_var}))	

		* Correlations 
		g v25 = causal_p25_czkr26_bm_se^2 + causal_p25_cty_kr26_bm_se^2 
		g prec25 = 1/v25
		g v75 = causal_p75_czkr26_am_se^2 + causal_p75_cty_kr26_am_se^2 
		g prec75 = 1/v75
		g weight = 1/(v25 + v75)
		
		corr causal_p25_cz_cty_kr26_bm causal_p75_cz_cty_kr26_am [w=weight]  , cov
		global cov = r(cov_12)
		
		su v25 [w=prec25] 
		global noise25 = r(mean)
		su causal_p25_cz_cty_kr26_bm [w=prec25]
		global totvar25 = r(Var)
		global sd25 = sqrt($totvar25 - $noise25)

		su v75 [w=prec75] 
		global noise75 = r(mean)
		su causal_p75_cz_cty_kr26_am [w=prec75] 
		global totvar75 = r(Var)
		global sd75 = sqrt($totvar75 - $noise75)

		global corr_cty = $cov / ($sd25 * $sd75)

		di $corr_cty
		
		tempfile ctyvar_p`p'
		save `ctyvar_p`p''
	
		* Store the correlation in the ctyvar matrix
		mat def ctyvar_p`p'[5,1] = ${corr_cty}
		
		preserve
		clear
		svmat2 ctyvar_p`p', rnames(variables)
		gen number = [_n]
		rename ctyvar_p`p'1 cty_se_kr26_p`p'
		order number variables 
		tempfile ctyvar_p`p'_mat
		save `ctyvar_p`p'_mat'
		restore
		}
		
		preserve 
		use `ctyvar_p25_mat', clear
		merge 1:1 number using `ctyvar_p75_mat', nogen
		tempfile ctyvar_full
		sa `ctyvar_full'
		restore 
		

	* C. Counties within CZ 
		
		* Compute covariance
		g weight_ctywincz = 1/(causal_p25_cty_kr26_bm_se^2 + causal_p75_cty_kr26_am_se^2 )
		areg causal_p25_cz_cty_kr26_bm causal_p75_cz_cty_kr26_am [w=weight_ctywincz]  , a(cz)
		global b_2575 = _b[causal_p75_cz_cty_kr26_am]
		areg causal_p75_cz_cty_kr26_am [w=weight_ctywincz] , a(cz)
		global sd_raw_75_2weight = e(rmse)
		global cov_2575 = $sd_raw_75_2weight * $b_2575

		* Compute Signal SDs
		g v25_cty_win_cz = causal_p25_cty_kr26_bm_se^2
		g v75_cty_win_cz = causal_p75_cty_kr26_am_se^2
		areg causal_p25_cz_cty_kr26_bm [w=1/v25_cty_win_cz] , a(cz)
		global sd_raw_25 = e(rmse)
		areg causal_p75_cz_cty_kr26_am [w=1/v75_cty_win_cz] , a(cz)
		global sd_raw_75 = e(rmse)
		su v25_cty_win_cz [w=1/v25_cty_win_cz]
		global sd_noise_25 = r(mean)
		su v75_cty_win_cz [w=1/v75_cty_win_cz]
		global sd_noise_75 = r(mean)
		global sd_sig_25 = sqrt($sd_raw_25^2 - $sd_noise_25^2)
		global sd_sig_75 = sqrt($sd_raw_75^2 - $sd_noise_75^2)
		
		* Calculate implied correlation
		global corr_cty_win_cz = $cov_2575 / ($sd_sig_25 * $sd_sig_75)
		di $corr_cty_win_cz

		foreach p in 25 75 {

		* Define matrix to store the results
		mat define cty_cz_var_p`p'=J(9,1,.)
		matrix rownames ctyvar_p`p'= ${namelist}
		
		* Store the correlation in the ctyvar matrix
		mat def cty_cz_var_p`p'[5,1] = $corr_cty_win_cz
		
		clear
		svmat2 cty_cz_var_p`p', rnames(variables)
		gen number = [_n]
		rename cty_cz_var_p`p'1 cty_cz_se_kr26_p`p'
		order number variables 
		tempfile cty_cz_var_p`p'
		save `cty_cz_var_p`p''
			}
			
		use `cty_cz_var_p25', clear
		merge 1:1 number using `cty_cz_var_p75', nogen
		tempfile cty_cz_var_full
		sa `cty_cz_var_full'
		
	* merge results together
	
		use `czvar_full'
		merge 1:1 number using `ctyvar_full', nogen
		merge 1:1 number using `cty_cz_var_full', nogen
		drop number
		
	* generate county within CZ results
	global name1 Raw_Exposure_Effect_(SD) Noise_(SD) Signal_of_Exposure_Effects_(SD) ///
	Causal_Effect_(SD_of_Signal) Permanent_Residents_(SD) ///
	Sorting_Component_(SD) 
	
	foreach p in 25 75 {
	
	* rows 1-2-3-6-7-8
	foreach name of global name1 {
	replace cty_cz_se_kr26_p`p' = sqrt(cty_se_kr26_p`p'^2 -cz_se_kr26_p`p'^2) if variables=="`name'"
	}
	
	* row 4
	sum cty_cz_se_kr26_p`p' if variables=="Noise_(SD)"
	global noise_p`p' = r(mean)

	sum cty_cz_se_kr26_p`p' if variables=="Signal_of_Exposure_Effects_(SD)"
	global signal_p`p' = r(mean)

	replace cty_cz_se_kr26_p`p' = ${signal_p`p'}^2 / ${noise_p`p'}^2 if variables=="Signal_to_Noise_Ratio"

	* row 9
	sum cty_cz_se_kr26_p`p' if variables=="Causal_Effect_(SD_of_Signal)"
	global causal_p`p' = r(mean)

	sum cty_cz_se_kr26_p`p' if variables=="Permanent_Residents_(SD)"
	global perm_res_p`p' = r(mean)
	
	sum cty_cz_se_kr26_p`p' if variables=="Sorting_Component_(SD)"
	global sort_comp_p`p' = r(mean)

	replace cty_cz_se_kr26_p`p' = (${perm_res_p`p'}^2 - ${sort_comp_p`p'}^2 - ${causal_p`p'}^2)/(2*${sort_comp_p`p'}*${causal_p`p'}) if variables=="Corr_Sorting_Causal"
	
	}
		
	outsheet using "${tables}/TableVII.csv",comma replace
	
* TABLE 8: Predicted Place Effects for the 50 Largest CZs

	use ${data}/Online_data_table1.dta, clear
	keep pop2000 czname stateabbrv  *p25_kr26 *p75_kr26
	order pop2000 czname stateabbrv  *p25_kr26 *p75_kr26
	gsort -pop2000
	keep in 1/50
	drop pop2000
	gsort -forecasts_p25_kr26
	outsheet using "${tables}/TableVIII.csv",comma replace
	
* TABLE 9: Predicted Place Effects for 100 Largest Counties (Top and Bottom 25)

	use ${data}/Online_data_table2.dta, clear
	gsort -cty_pop2000
	g pop_rank = _n
	keep if pop_rank<=100
	gsort -forecasts_p25_kr26
	gen effect_rank = _n
	keep if effect_rank <= 25 | effect_rank >= 75
	keep county_name stateabbrv *p25_kr26 *p75_kr26
	outsheet using "${tables}/TableIX.csv",comma replace
	
* TABLE 10: Predicted Place Effects for 50 largest CZs for Below-median Income Male, Female, Average, Pooled

	use ${data}/Online_data_table1.dta, clear
	gsort -pop2000
	keep in 1/50
	gsort -forecasts_p25_kr26_avg
	keep cz stateabbrv *p25_kr26_m *p25_kr26_f *p25_kr26 *p25_kr26_avg 
	order cz stateabbrv *p25_kr26_m *p25_kr26_f *p25_kr26 *p25_kr26_avg
	drop dollar*
	outsheet using "${tables}/TableX.csv",comma replace

	
* TABLE 11: Predicted Place Effects for 100 Largest Counties (Top and Bottom 25) based on Family Income Rank: Male, Female, Average, Pooled

	use ${data}/Online_data_table2.dta, clear
	gsort -cty_pop2000
	g pop_rank = _n
	keep if pop_rank<=100
	gsort -forecasts_p25_kr26_avg
	gen effect_rank = _n
	keep if effect_rank <= 25 | effect_rank >= 75
	keep county_name stateabbrv *p25_kr26_m *p25_kr26_f *p25_kr26 *p25_kr26_avg 
	order county_name stateabbrv *p25_kr26_m *p25_kr26_f *p25_kr26 *p25_kr26_avg
	drop dollar*
	outsheet using "${tables}/TableXI.csv",comma replace

* TABLE 12: Regressions of Place Effects Across Commuting Zones on Selected Covariates (Below-Median Income Parents (p25)) 
	
	* Define Selected Covariates
	global varlist cs_race_bla poor_share cs_race_theil_2000 cs00_seg_inc cs00_seg_inc_pov25 cs00_seg_inc_aff75 frac_traveltime_lt15 log_pop_density ///
	hhinc00 gini inc_share_1perc gini99 frac_middleclass ///
	taxrate subcty_total_taxes_pc subcty_total_expenditure_pc eitc_exposure tax_st_diff_top20 ///
	ccd_exp_tot ccd_pup_tch_ratio score_r dropout_r ///
	num_inst_pc tuition gradrate_r ///
	cs_labforce cs_elf_ind_man d_tradeusch_pw_1990 frac_worked1416 ///
	mig_inflow mig_outflow cs_born_foreign ///
	scap_ski90pcm rel_tot crime_violent ///
	cs_fam_wkidsinglemom cs_divorced cs_married ///
	median_house_value median_rent
	
	* define scale factor (baseline is 20 years of exposure)
	global scale_factor =20
	
	* use beta dataset
	use ${data}/Online_data_table3.dta, clear
	
	* define matrix to store results 
	mat define reg=J(40,9,.)
	local row =1
	matrix rownames reg= ${varlist}
	
	*Drop all obs with missing values of stayers, which are necessary for decomposition into sorting and causal
	keep if perm_res_p25_kr26~=.
	
	*Estimates of causal and sorting effects
	g causal = ${scale_factor}*causal_p25_czkr26
	g sorting = perm_res_p25_kr26-causal

	*Generate variances and precision weights
	g causal_var_p25_czkr26_bs = causal_p25_czkr26_bs_se^2
	g precwt = 1/causal_var_p25_czkr26_bs
	
	* estimate signal and noise variances 
	qui sum causal_var_p25_czkr26_bs [w=precwt]
	global noisevar = r(mean)
	qui sum causal_p25_czkr26 [w=precwt],d
	global totvar = r(Var)

	global sigvar = $totvar-$noisevar
	assert ${sigvar}>0
	global sigsd = sqrt($sigvar)
	
	* Regressions with Observables
	foreach var of global varlist {
	sum `var' [w=pop2000]
	global st_dev = r(sd)
	mat def reg[`row',1] = ${st_dev}
	
	qui reg causal_p25_czkr26 `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',2] = _b[`var'_st]/${sigsd}
	mat def reg[`row',3] = _se[`var'_st]/${sigsd}
	
	qui reg perm_res_p25_kr26 `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',4] = _b[`var'_st]
	mat def reg[`row',5] = _se[`var'_st]
	
	qui reg causal `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',6] = _b[`var'_st]
	mat def reg[`row',7] = _se[`var'_st]
	
	qui reg sorting `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',8] = _b[`var'_st]
	mat def reg[`row',9] = _se[`var'_st]
	local row = `row'+1
	}
	
	* store results in a matrix
	clear
	svmat2 reg, rnames(variables)
	gen number = [_n]
	rename reg1 std_dev_kr26_p25
	rename reg2 coef_corr_kr26_p25
	rename reg3 se_corr_kr26_p25
	rename reg4 coef_stayers_kr26_p25
	rename reg5 se_stayers_kr26_p25
	rename reg6 coef_causal_kr26_p25
	rename reg7 se_causal_kr26_p25
	rename reg8 coef_sorting_kr26_p25
	rename reg9 se_sorting_kr26_p25
	order number variables std* coef_corr* se_corr* coef_stayers* se_stayers* coef_causal* se_causal* coef_sorting* se_sorting*
	drop number
	
	outsheet using "${tables}/TableXII.csv",comma replace
	
* TABLE 13: Regressions of Place Effects Across Commuting Zones on Selected Covariates (Above-Median Income Parents (p75)) 

	* Define Selected Covariates
	global varlist cs_race_bla poor_share cs_race_theil_2000 cs00_seg_inc cs00_seg_inc_pov25 cs00_seg_inc_aff75 frac_traveltime_lt15 log_pop_density ///
	hhinc00 gini inc_share_1perc gini99 frac_middleclass ///
	taxrate subcty_total_taxes_pc subcty_total_expenditure_pc eitc_exposure tax_st_diff_top20 ///
	ccd_exp_tot ccd_pup_tch_ratio score_r dropout_r ///
	num_inst_pc tuition gradrate_r ///
	cs_labforce cs_elf_ind_man d_tradeusch_pw_1990 frac_worked1416 ///
	mig_inflow mig_outflow cs_born_foreign ///
	scap_ski90pcm rel_tot crime_violent ///
	cs_fam_wkidsinglemom cs_divorced cs_married ///
	median_house_value median_rent
	
	* define scale factor (baseline is 20 years of exposure)
	global scale_factor =20
	
	* use beta dataset
	use ${data}/Online_data_table3.dta, clear
	
	* define matrix to store results 
	mat define reg=J(40,9,.)
	local row =1
	matrix rownames reg= ${varlist}
	
	*Drop all obs with missing values of stayers, which are necessary for decomposition into sorting and causal
	keep if perm_res_p75_kr26~=.
	
	*Estimates of causal and sorting effects
	g causal = ${scale_factor}*causal_p75_czkr26
	g sorting = perm_res_p75_kr26-causal

	*Generate variances and precision weights
	g causal_var_p75_czkr26_bs = causal_p75_czkr26_bs_se^2
	g precwt = 1/causal_var_p75_czkr26_bs
	
	* estimate signal and noise variances 
	qui sum causal_var_p75_czkr26_bs [w=precwt]
	global noisevar = r(mean)
	qui sum causal_p75_czkr26 [w=precwt],d
	global totvar = r(Var)

	global sigvar = $totvar-$noisevar
	assert ${sigvar}>0
	global sigsd = sqrt($sigvar)
	
	* Regressions with Observables
	foreach var of global varlist {
	sum `var' [w=pop2000]
	global st_dev = r(sd)
	mat def reg[`row',1] = ${st_dev}
	
	qui reg causal_p75_czkr26 `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',2] = _b[`var'_st]/${sigsd}
	mat def reg[`row',3] = _se[`var'_st]/${sigsd}
	
	qui reg perm_res_p75_kr26 `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',4] = _b[`var'_st]
	mat def reg[`row',5] = _se[`var'_st]
	
	qui reg causal `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',6] = _b[`var'_st]
	mat def reg[`row',7] = _se[`var'_st]
	
	qui reg sorting `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',8] = _b[`var'_st]
	mat def reg[`row',9] = _se[`var'_st]
	local row = `row'+1
	}
	
	* store results in a matrix
	clear
	svmat2 reg, rnames(variables)
	gen number = [_n]
	rename reg1 std_dev_kr26_p75
	rename reg2 coef_corr_kr26_p75
	rename reg3 se_corr_kr26_p75
	rename reg4 coef_stayers_kr26_p75
	rename reg5 se_stayers_kr26_p75
	rename reg6 coef_causal_kr26_p75
	rename reg7 se_causal_kr26_p75
	rename reg8 coef_sorting_kr26_p75
	rename reg9 se_sorting_kr26_p75
	order number variables std* coef_corr* se_corr* coef_stayers* se_stayers* coef_causal* se_causal* coef_sorting* se_sorting*
	drop number
	
	outsheet using "${tables}/TableXIII.csv",comma replace

* TABLE 14: Regressions of Place Effects Across Counties within Commuting Zones on Selected Covariates (Below-Median Income Parents (p25)) 
	
	* Define Selected Covariates
	global varlist cs_race_bla poor_share cs_race_theil_2000 cs00_seg_inc cs00_seg_inc_pov25 cs00_seg_inc_aff75 frac_traveltime_lt15 log_pop_density ///
	hhinc00 gini inc_share_1perc gini99 frac_middleclass ///
	taxrate subcty_total_taxes_pc subcty_total_expenditure_pc eitc_exposure tax_st_diff_top20 ///
	ccd_exp_tot ccd_pup_tch_ratio score_r dropout_r ///
	num_inst_pc tuition gradrate_r ///
	cs_labforce cs_elf_ind_man frac_worked1416 ///
	mig_inflow mig_outflow cs_born_foreign ///
	scap_ski90pcm rel_tot crime_violent ///
	cs_fam_wkidsinglemom cs_divorced cs_married ///
	median_house_value median_rent 
	
	* define scale factor (baseline is 20 years of exposure)
	global scale_factor =20
	
	* define matrix to store results 
	mat define reg=J(39,9,.)
	local row =1
	matrix rownames reg= ${varlist}
	
	* Save Signal Variance at the CZ level 
	
		* use beta dataset
		use ${data}/Online_data_table3.dta, clear
		
		*Drop all obs with missing values of stayers, which are necessary for decomposition into sorting and causal
		keep if perm_res_p25_kr26~=.

		*Generate variances and precision weights
		g causal_var_p25_czkr26_bs = causal_p25_czkr26_bs_se^2
		g precwt = 1/causal_var_p25_czkr26_bs
		
		* estimate signal and noise variances 
		qui sum causal_var_p25_czkr26_bs [w=precwt]
		global noisevar_cz = r(mean)
		qui sum causal_p25_czkr26 [w=precwt],d
		global totvar_cz = r(Var)

		global sigvar_cz = $totvar_cz-$noisevar_cz

	* County within CZ regressions 
	
		* Define Population cutoffs
		macro drop cz_pop_cutoff cty_pop_cutoff
		global cz_pop_cutoff 25000
		global cty_pop_cutoff 10000
	
		* use beta dataset
		use ${data}/Online_data_table4.dta, clear
		bys cz: gen cty_by_cz = _N
	
		* Merge with CZ level estimates from Online Data Table 3
		merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p25_czkr26 causal_p25_czkr26_bs_se ) nogen
		replace causal_p25_czkr26 =. if cz_pop2000<${cz_pop_cutoff} | cty_pop2000<${cty_pop_cutoff}
		replace causal_p25_czkr26_bs_se=. if cz_pop2000<${cz_pop_cutoff} | cty_pop2000<${cty_pop_cutoff}
		su causal_p25_czkr26 [w=cz_pop2000/cty_by_cz]
		replace causal_p25_czkr26 = causal_p25_czkr26-r(mean)
		
		* compute Commuting Zone plus County estimates 
		g causal_p25_czct_kr26 = causal_p25_czkr26 + causal_p25_cty_kr26
		replace causal_p25_czct_kr26 = causal_p25_czkr26 if causal_p25_cty_kr26==. & cty_by_cz==1
		
		* compute Commuting Zone plus County standard errors
		g causal_p25_czct_kr26_bs_se = sqrt(causal_p25_cty_kr26_se^2+(causal_p25_czkr26_bs_se^2))
		replace causal_p25_czct_kr26_bs_se = causal_p25_czkr26_bs_se if causal_p25_czct_kr26_bs_se ==. & causal_p25_czct_kr26~=.
		
		*Drop all obs with missing values of permanent residents, which are necessary for predictions
		keep if perm_res_p25_kr26~=.
		
		*Generate variances and precision weights
		g causal_var_p25_czctkr26_bs = causal_p25_czct_kr26_bs_se ^2
		g precwt = 1/causal_var_p25_czctkr26_bs
		
		* estimate signal and noise variances 
		qui sum causal_var_p25_czctkr26_bs [w=precwt]
		global noisevar = r(mean)
		qui sum causal_p25_czct_kr26 [w=precwt],d
		global totvar = r(Var)

		global sigvar = $totvar-$noisevar
		
		* Estimating signal SD of county within cz
		global sigsd_within = sqrt(${sigvar} - ${sigvar_cz})
	
		*Estimates of causal and sorting effects
		g causal = ${scale_factor}*causal_p25_czct_kr26
		g sorting = perm_res_p25_kr26-causal
	
	* Regressions with Observables
	
		foreach var of global varlist {
		sum `var' [w=cty_pop2000]
		global st_dev = r(sd)
		mat def reg[`row',1] = ${st_dev}
		
		qui areg causal_p25_czct_kr26 `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',2] = _b[`var'_st]/${sigsd_within}
		mat def reg[`row',3] = _se[`var'_st]/${sigsd_within}
		
		qui areg perm_res_p25_kr26 `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',4] = _b[`var'_st]
		mat def reg[`row',5] = _se[`var'_st]
		
		qui areg causal `var'_st [w=cty_pop2000],  absorb(cz) cluster(cz)
		mat def reg[`row',6] = _b[`var'_st]
		mat def reg[`row',7] = _se[`var'_st]
		
		qui areg sorting `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',8] = _b[`var'_st]
		mat def reg[`row',9] = _se[`var'_st]
		local row = `row'+1
		}
	
	* store results in a matrix
		clear
		svmat2 reg, rnames(variables)
		gen number = [_n]
		rename reg1 std_dev_kr26_p25
		rename reg2 coef_corr_kr26_p25
		rename reg3 se_corr_kr26_p25
		rename reg4 coef_stayers_kr26_p25
		rename reg5 se_stayers_kr26_p25
		rename reg6 coef_causal_kr26_p25
		rename reg7 se_causal_kr26_p25
		rename reg8 coef_sorting_kr26_p25
		rename reg9 se_sorting_kr26_p25
		order number variables std* coef_corr* se_corr* coef_stayers* se_stayers* coef_causal* se_causal* coef_sorting* se_sorting*
		drop number
	
	outsheet using "${tables}/TableXIV.csv",comma replace
	
* TABLE 15: Regressions of Place Effects Across Counties within Commuting Zones on Selected Covariates (Above-Median Income Parents (p75)) 

	* Define Selected Covariates
	global varlist cs_race_bla poor_share cs_race_theil_2000 cs00_seg_inc cs00_seg_inc_pov25 cs00_seg_inc_aff75 frac_traveltime_lt15 log_pop_density ///
	hhinc00 gini inc_share_1perc gini99 frac_middleclass ///
	taxrate subcty_total_taxes_pc subcty_total_expenditure_pc eitc_exposure tax_st_diff_top20 ///
	ccd_exp_tot ccd_pup_tch_ratio score_r dropout_r ///
	num_inst_pc tuition gradrate_r ///
	cs_labforce cs_elf_ind_man frac_worked1416 ///
	mig_inflow mig_outflow cs_born_foreign ///
	scap_ski90pcm rel_tot crime_violent ///
	cs_fam_wkidsinglemom cs_divorced cs_married ///
	median_house_value median_rent 
	
	* define scale factor (baseline is 20 years of exposure)
	global scale_factor =20
	
	* define matrix to store results 
	mat define reg=J(39,9,.)
	local row =1
	matrix rownames reg= ${varlist}
	
	* Save Signal Variance at the CZ level 
	
		* use beta dataset
		use ${data}/Online_data_table3.dta, clear
		
		*Drop all obs with missing values of stayers, which are necessary for decomposition into sorting and causal
		keep if perm_res_p75_kr26~=.

		*Generate variances and precision weights
		g causal_var_p75_czkr26_bs = causal_p75_czkr26_bs_se^2
		g precwt = 1/causal_var_p75_czkr26_bs
		
		* estimate signal and noise variances 
		qui sum causal_var_p75_czkr26_bs [w=precwt]
		global noisevar_cz = r(mean)
		qui sum causal_p75_czkr26 [w=precwt],d
		global totvar_cz = r(Var)

		global sigvar_cz = $totvar_cz-$noisevar_cz

	* County within CZ regressions 
	
		* Define Population cutoffs
		macro drop cz_pop_cutoff cty_pop_cutoff
		global cz_pop_cutoff 25000
		global cty_pop_cutoff 10000
	
		* use beta dataset
		use ${data}/Online_data_table4.dta, clear
		bys cz: gen cty_by_cz = _N
	
		* Merge with CZ level estimates from Online Data Table 3
		merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p75_czkr26 causal_p75_czkr26_bs_se ) nogen
		replace causal_p75_czkr26 =. if cz_pop2000<${cz_pop_cutoff} | cty_pop2000<${cty_pop_cutoff}
		replace causal_p75_czkr26_bs_se=. if cz_pop2000<${cz_pop_cutoff} | cty_pop2000<${cty_pop_cutoff}
		su causal_p75_czkr26 [w=cz_pop2000/cty_by_cz]
		replace causal_p75_czkr26 = causal_p75_czkr26-r(mean)
		
		* compute Commuting Zone plus County estimates 
		g causal_p75_czct_kr26 = causal_p75_czkr26 + causal_p75_cty_kr26
		replace causal_p75_czct_kr26 = causal_p75_czkr26 if causal_p75_cty_kr26==. & cty_by_cz==1
		
		* compute Commuting Zone plus County standard errors
		g causal_p75_czct_kr26_bs_se = sqrt(causal_p75_cty_kr26_se^2+(causal_p75_czkr26_bs_se^2))
		replace causal_p75_czct_kr26_bs_se = causal_p75_czkr26_bs_se if causal_p75_czct_kr26_bs_se ==. & causal_p75_czct_kr26~=.
		
		*Drop all obs with missing values of permanent residents, which are necessary for predictions
		keep if perm_res_p75_kr26~=.
		
		*Generate variances and precision weights
		g causal_var_p75_czctkr26_bs = causal_p75_czct_kr26_bs_se ^2
		g precwt = 1/causal_var_p75_czctkr26_bs
		
		* estimate signal and noise variances 
		qui sum causal_var_p75_czctkr26_bs [w=precwt]
		global noisevar = r(mean)
		qui sum causal_p75_czct_kr26 [w=precwt],d
		global totvar = r(Var)

		global sigvar = $totvar-$noisevar
		
		* Estimating signal SD of county within cz
		global sigsd_within = sqrt(${sigvar} - ${sigvar_cz})
	
		*Estimates of causal and sorting effects
		g causal = ${scale_factor}*causal_p75_czct_kr26
		g sorting = perm_res_p75_kr26-causal
	
	* Regressions with Observables
	
		foreach var of global varlist {
		sum `var' [w=cty_pop2000]
		global st_dev = r(sd)
		mat def reg[`row',1] = ${st_dev}
		
		qui areg causal_p75_czct_kr26 `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',2] = _b[`var'_st]/${sigsd_within}
		mat def reg[`row',3] = _se[`var'_st]/${sigsd_within}
		
		qui areg perm_res_p75_kr26 `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',4] = _b[`var'_st]
		mat def reg[`row',5] = _se[`var'_st]
		
		qui areg causal `var'_st [w=cty_pop2000],  absorb(cz) cluster(cz)
		mat def reg[`row',6] = _b[`var'_st]
		mat def reg[`row',7] = _se[`var'_st]
		
		qui areg sorting `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',8] = _b[`var'_st]
		mat def reg[`row',9] = _se[`var'_st]
		local row = `row'+1
		}
	
	* store results in a matrix
		clear
		svmat2 reg, rnames(variables)
		gen number = [_n]
		rename reg1 std_dev_kr26_p75
		rename reg2 coef_corr_kr26_p75
		rename reg3 se_corr_kr26_p75
		rename reg4 coef_stayers_kr26_p75
		rename reg5 se_stayers_kr26_p75
		rename reg6 coef_causal_kr26_p75
		rename reg7 se_causal_kr26_p75
		rename reg8 coef_sorting_kr26_p75
		rename reg9 se_sorting_kr26_p75
		order number variables std* coef_corr* se_corr* coef_stayers* se_stayers* coef_causal* se_causal* coef_sorting* se_sorting*
		drop number
	
	outsheet using "${tables}/TableXV.csv",comma replace
	
	
*************************** PART V - APPENDIX TABLES ***************************

* APPENDIX TABLE 4: Prediction Regressions

* Define prediction components
	macro drop namelist
	global namelist Stayers_Reg_Coeff s.e. SD_of_predicted_values SD_of_residual_values /// 
	Noise_SD_of_residuals Signal_SD_of_residuals Num_of_Obs
	
* A. Commuting Zone Level Prediction Regressions
	
		foreach p in 25 75 {
		
		* Define matrix to store the results
		mat define pred_p`p'=J(7,1,.)
		matrix rownames pred_p`p'= ${namelist}
		
		* Use online data table 3
		use ${data}/Online_data_table3.dta, clear
		
		*Drop all observations with missing values of permanent residents, which are necessary for predictions
		keep if perm_res_p`p'_kr26~=.
		
		*Generate variances and precision weights
		g causal_var_p`p'_czkr26_bs = causal_p`p'_czkr26_bs_se^2
		g precwt = 1/causal_var_p`p'_czkr26_bs
		
		* estimate noise variances 
		qui sum causal_var_p`p'_czkr26_bs [w=precwt]
		global noisevar = r(mean)
		
		* estimate permanent residents predictions
		qui reg causal_p`p'_czkr26 perm_res_p`p'_kr26 [w=precwt]
		global stayers_raw_coeff = _b[perm_res_p`p'_kr26]
		global stayers_raw_se = _se[perm_res_p`p'_kr26]
		global num = e(N)
		global Rsq_stayers = e(r2)
		predict causal_pred, xb
		predict causal_resid, r
		
		*Predicted estimates using permanent residents predictions
		su causal_pred [w=precwt]
		global pred_sd = r(sd)
		sum causal_resid [w=precwt]
		global resid_sd = r(sd)
		global resid_sigvar = r(sd)^2 - $noisevar
		assert ${resid_sigvar}>0
		
		* store predictions regression results
		mat def pred_p`p'[1,1] = ${stayers_raw_coeff}
		mat def pred_p`p'[2,1] = ${stayers_raw_se}
		mat def pred_p`p'[3,1] = ${pred_sd}
		mat def pred_p`p'[4,1] = ${resid_sd}  
		mat def pred_p`p'[5,1] = sqrt(${noisevar})
		mat def pred_p`p'[6,1] = sqrt(${resid_sigvar})
		mat def pred_p`p'[7,1] = ${num}
		
		* store results in the pred matrix
		clear
		svmat2 pred_p`p', rnames(variables)
		gen number = [_n]
		rename pred_p`p'1 p`p'_cz
		order number variables p*
		tempfile pred_p`p'
		save `pred_p`p''
		
		}

		*organize commuting-zone level results
		use `pred_p25', clear
		merge 1:1 number using `pred_p75', nogen
		tempfile cz
		sa `cz'
	
* B. County Level Prediction Regressions
	
		* Define Population Cutoff
		macro drop cz_pop_cutoff cty_pop_cutoff
		global cz_pop_cutoff 25000
		global cty_pop_cutoff 10000
		
		foreach p in 25 75 {
		
		* Define matrix to store the results
		mat define pred_p`p'=J(7,1,.)
		matrix rownames pred_p`p'= ${namelist}
		
		* Use online data table 3
		use ${data}/Online_data_table4.dta, clear
		
		* Merge with CZ level estimates from Online Data Table 3
		merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p`p'_czkr26 causal_p`p'_czkr26_bs_se) nogen

		* compute CZ plus CTY estimates and variance
		g causal_p`p'_czct_kr26_bs_se = sqrt(causal_p`p'_cty_kr26_se^2+(causal_p`p'_czkr26_bs_se^2))
		replace causal_p`p'_czct_kr26_bs_se = causal_p`p'_czkr26_bs_se if causal_p`p'_czct_kr26_bs_se ==. & causal_p`p'_cz_cty_kr26~=.
		rename causal_p`p'_cz_cty_kr26 causal_p`p'_czct_kr26
		
		*Drop all obs with missing values of permanent residents, which are necessary for predictions
		keep if perm_res_p`p'_kr26~=.
		
		*Generate variances and precision weights
		g causal_var_p`p'_czctkr26_bs = causal_p`p'_czct_kr26_bs_se ^2
		g precwt = 1/causal_var_p`p'_czctkr26_bs
		
		* estimate noise variances 
		qui sum causal_var_p`p'_czctkr26_bs [w=precwt]
		global noisevar = r(mean)
		
		* estimate permanent residents predictions
		qui reg causal_p`p'_czct_kr26 perm_res_p`p'_kr26 [w=precwt]
		global stayers_raw_coeff = _b[perm_res_p`p'_kr26]
		global stayers_raw_se = _se[perm_res_p`p'_kr26]
		global num = e(N)
		global Rsq_stayers = e(r2)
		predict causal_pred, xb
		predict causal_resid, r
		
		*Predicted estimates using permanent residents predictions
		sum causal_pred [w=precwt]
		global pred_sd = r(sd)
		sum causal_resid [w=precwt]
		global resid_sd = r(sd)
		global resid_sigvar = r(sd)^2 - $noisevar
		di $resid_sigvar
		assert ${resid_sigvar}>0

		* store predictions regression results
		mat def pred_p`p'[1,1] = ${stayers_raw_coeff}
		mat def pred_p`p'[2,1] = ${stayers_raw_se}
		mat def pred_p`p'[3,1] = ${pred_sd}
		mat def pred_p`p'[4,1] = ${resid_sd}  
		mat def pred_p`p'[5,1] = sqrt(${noisevar})
		mat def pred_p`p'[6,1] = sqrt(${resid_sigvar})
		mat def pred_p`p'[7,1] = ${num}
		
		* store results in the pred matrix
		clear
		svmat2 pred_p`p', rnames(variables)
		gen number = [_n]
		rename pred_p`p'1 p`p'_cty
		order number variables p*
		tempfile pred_p`p'
		save `pred_p`p''
		}
		
		*organize county level results
		use `pred_p25', clear
		merge 1:1 number using `pred_p75', nogen
		tempfile cty
		sa `cty'
		
	use `cz', clear
	merge 1:1 number using `cty', nogen
	drop number
	outsheet using "${tables}/AppendixTableIV.csv",comma replace

	
* APPENDIX TABLE 5: Correlates of Alternative Measures of Place Effects

	* Define list of specifications
	macro drop namelist
	global namelist kr26 kr26_drc kr26_sq kr26_bm kr26_am kr26_coli ///
	kir26 kr26_m kr26_f kir26_m kir26_f kii26 kfi26
	
	* A. Commuting Zone Correlations
	
		foreach p in 25 75{
		
			* Define Matrix to store the results 
			mat define corrspec_p`p'=J(13,2,.)
			matrix rownames corrspec_p`p'= ${namelist}
			local row =1
		
		foreach outcome of global namelist {
		
			* Use online data table 3
			use ${data}/Online_data_table3.dta, clear
			
			*Drop all observations with missing values of permanent residents, which are necessary for predictions
			if "`outcome'"=="kr26_drc" {
			g perm_res_p`p'_`outcome' = perm_res_p`p'_kr26
			}
			keep if perm_res_p`p'_`outcome'~=.
			
			*Generate variances and precision weights
			if "`outcome'"=="kr26" | "`outcome'"=="kir26" {
			g causal_var_p`p'_cz`outcome'_bs = causal_p`p'_cz`outcome'_bs_se^2
			}
			else{ 
			g causal_var_p`p'_cz`outcome'_bs = causal_p`p'_cz`outcome'_se^2
			}
			g precwt = 1/causal_var_p`p'_cz`outcome'_bs
			
			* estimate signal and noise variances 
			qui sum causal_var_p`p'_cz`outcome'_bs [w=precwt]
			global noisevar = r(mean)
			qui sum causal_p`p'_cz`outcome'[w=precwt],d
			global totvar = r(Var)
			global sigvar = $totvar-$noisevar
			assert ${sigvar}>0

			* Generate weights for Correlations
			if "`outcome'"=="kr26" | "`outcome'"=="kir26" {
			g v_cz`outcome' = causal_p`p'_cz`outcome'_bs_se^2 + causal_p`p'_czkr26_bs_se^2
			}
			else{ 
			g v_cz`outcome' = causal_p`p'_cz`outcome'_se^2 + causal_p`p'_czkr26_bs_se^2
			}
			g precwt_2 = 1/v_cz`outcome'

			* Correlations with Observables
			corr  causal_p`p'_cz`outcome' causal_p`p'_czkr26 [w=precwt_2]
			mat def corrspec_p`p'[`row',1] = r(rho)
			mat def corrspec_p`p'[`row',2] = sqrt($sigvar)
			local row = `row'+1
			}
			
			* store results in the corrspec matrix
			clear
			svmat2 corrspec_p`p', rnames(variables)
			gen number = [_n]
			rename corrspec_p`p'1 corr_p`p'
			rename corrspec_p`p'2 signal_sd_p`p'
			order number variables corr_* signal_sd*
			tempfile cz_p`p'
			save `cz_p`p''
		}
	
	use `cz_p25', clear
	merge 1:1 number using `cz_p75', nogen
	tempfile CZ 
	save `CZ'

	* A. County Correlations
	
			foreach p in 25 75{
		
			* Define Matrix to store the results 
			mat define corrspec_p`p'=J(13,2,.)
			matrix rownames corrspec_p`p'= ${namelist}
			local row =1
		
		foreach outcome of global namelist {
	
			* Define Population Cutoffs
			macro drop cz_pop_cutoff cty_pop_cutoff
			global cz_pop_cutoff 25000
			global cty_pop_cutoff 10000
	
			*Use Online Data Table 4
			use ${data}/Online_data_table4.dta, clear
			
			* Merge with CZ level estimates from Online Data Table 3
			if "`outcome'" =="kr26" | "`outcome'" =="kir26" {
			}
			else{
			merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p`p'_cz`outcome' causal_p`p'_cz`outcome'_se) nogen
			gen causal_p`p'_cz`outcome'_bs_se = causal_p`p'_cz`outcome'_se
			
			* compute CZ plus CTY estimates and variance
			g causal_p`p'_czct_`outcome'_bs_se = sqrt(causal_p`p'_cty_`outcome'_se^2+(causal_p`p'_cz`outcome'_bs_se^2))
			replace causal_p`p'_czct_`outcome'_bs_se = causal_p`p'_cz`outcome'_bs_se if causal_p`p'_czct_`outcome'_bs_se ==. & causal_p`p'_cz_cty_`outcome'~=.
			rename causal_p`p'_cz_cty_`outcome' causal_p`p'_czct_`outcome'
			}
		
				foreach varoutcome in "kr26" "kir26" {	
					merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p`p'_cz`varoutcome' causal_p`p'_cz`varoutcome'_bs_se) nogen
			
					* compute CZ plus CTY estimates and variance
					g causal_p`p'_czct_`varoutcome'_bs_se = sqrt(causal_p`p'_cty_`varoutcome'_se^2+(causal_p`p'_cz`varoutcome'_bs_se^2))
					replace causal_p`p'_czct_`varoutcome'_bs_se = causal_p`p'_cz`varoutcome'_bs_se if causal_p`p'_czct_`varoutcome'_bs_se ==. & causal_p`p'_cz_cty_`varoutcome'~=.
					rename causal_p`p'_cz_cty_`varoutcome' causal_p`p'_czct_`varoutcome'
				}
				
			*Drop all obs with missing values of permanent residents, which are necessary for predictions
			if "`outcome'"=="kr26_drc" {
			g perm_res_p`p'_`outcome' = perm_res_p`p'_kr26
			}
			keep if perm_res_p`p'_`outcome'~=.
	
			*Generate variances and precision weights
			g causal_var_p`p'_czct`outcome'_bs = causal_p`p'_czct_`outcome'_bs_se ^2
			g precwt = 1/causal_var_p`p'_czct`outcome'_bs
			
			* estimate signal and noise variances 
			qui sum causal_var_p`p'_czct`outcome'_bs [w=precwt]
			global noisevar = r(mean)
			qui sum causal_p`p'_czct_`outcome'[w=precwt],d
			global totvar = r(Var)
			global sigvar = $totvar-$noisevar
			*assert ${sigvar}>0
			
			* Generate weights for Correlations
			g v_czct`outcome' = causal_p`p'_czct_`outcome'_bs_se^2 + causal_p`p'_czct_kr26_bs_se^2
			g precwt_2 = 1/v_czct`outcome'

			* Correlations with Observables
			corr  causal_p`p'_czct_`outcome' causal_p`p'_czct_kr26 [w=precwt_2]
			mat def corrspec_p`p'[`row',1] = r(rho)
			mat def corrspec_p`p'[`row',2] = sqrt($sigvar)
			local row = `row'+1
			}
			
			* store results in the corrspec matrix
			clear
			svmat2 corrspec_p`p', rnames(variables)
			gen number = [_n]
			rename corrspec_p`p'1 corr_p`p'
			rename corrspec_p`p'2 signal_sd_p`p'
			order number variables corr_* signal_sd*
			tempfile cty_p`p'
			save `cty_p`p''
			}
	
		use `cty_p25', clear
		merge 1:1 number using `cty_p75', nogen
		tempfile CTY 
		save `CTY'
		
		use `CZ', clear 
		append using `CTY'
		drop number 
		
		outsheet using "${tables}/AppendixTableV.csv",comma replace	

	
* APPENDIX TABLE 6: Decomposition into Causal and Sorting Component

macro drop scale_factor
global scale_factor =20

	foreach p in 25 75{
	use ${data}/Online_data_table3.dta, clear
	
	*Drop all obs with missing values of stayers, which are necessary for decomposition into causal and sorting
	keep if perm_res_p`p'_kr26~=.
	
	*Estimates of causal and sorting effects
	g causal_p`p'_kr26 = ${scale_factor}*causal_p`p'_czkr26
	g sorting_p`p'_kr26 = perm_res_p`p'_kr26 - causal_p`p'_kr26
	g causal_se_p`p'_kr26 = ${scale_factor}*causal_p`p'_czkr26_bs_se
	
	* Keep only the variables of interest
	keep cz stateabbrv czname perm_res_p`p'_kr26 causal_p`p'_kr26 sorting_p`p'_kr26 causal_se_p`p'_kr26 pop2000
	order czname stateabbrv perm_res_p`p'_kr26  sorting_p`p'_kr26 causal_p`p'_kr26 causal_se_p`p'_kr26
	
	* Keep only the Top10 cz's
	gsort -pop2000
	keep in 1/10
	tempfile kr26_p`p'
	save `kr26_p`p''
	}
	use `kr26_p25', clear
	merge 1:1 cz using `kr26_p75', nogen 
	gsort -pop2000
	drop cz pop2000
	
	outsheet using "${tables}/AppendixTableVI.csv",comma replace	

	
* APPENDIX TABLE 7: Model Variance Components: Robusntess to Alternative Tc Assumptions
	
	* Define variance components
	macro drop namelist
	global namelist Causal_Effect_(SD_of_Signal) Permanent_Residents_(SD) ///
	Sorting_Component_(SD) Corr_Sorting_Causal
		
	* A commuting Zone Level 
	
		foreach scale_factor in 20 23 12{

		foreach p in 25 75 {
		
		* Use CZ level dataset
		use ${data}/Online_data_table3.dta, clear
		
		* Define matrix to store the results
		mat define czvar_p`p'=J(4,1,.)
		matrix rownames czvar_p`p'= ${namelist}
	
		*Drop all obs with missing values of stayers, which are necessary for predictions
		keep if perm_res_p`p'_kr26~=.
	 
		*Generate variances and precision weights
		g causal_var_p`p'_czkr26_bs = causal_p`p'_czkr26_bs_se^2
		g precwt = 1/causal_var_p`p'_czkr26_bs	
		
		* estimate signal and noise variances 
		qui sum causal_var_p`p'_czkr26_bs [w=precwt]
		global noisevar = r(mean)
		
		qui sum causal_p`p'_czkr26 [w=precwt],d
		global totvar = r(Var)
		
		global sigvar = $totvar-$noisevar
		assert ${sigvar}>0
		global sigsd = sqrt($sigvar)
	
		*Estimates of causal and sorting effects
		g causal_p`p' = `scale_factor'*causal_p`p'_czkr26
		g sorting_p`p' = perm_res_p`p'_kr26-causal_p`p'
		
		*Variance decomposition
		qui sum perm_res_p`p'_kr26 [w=precwt]
		global stayers_var = r(Var)
		
		*Signal variance of causal effects
		global causal_var = (`scale_factor'*${sigsd})^2
		
		*Covariance of causal effects and sorting
		reg causal_p`p' perm_res_p`p'_kr26 [w=precwt]
		global covar_causal_sorting = _b[perm_res_p`p'_kr26]*${stayers_var}-${causal_var}
		global sorting_var = ${stayers_var}-${causal_var}-2*${covar_causal_sorting}
	
		* store the results
		mat def czvar_p`p'[1,1] = sqrt(${causal_var})
		mat def czvar_p`p'[2,1] = sqrt(${stayers_var})
		mat def czvar_p`p'[3,1] = sqrt($sorting_var)
		mat def czvar_p`p'[4,1] = ${covar_causal_sorting}/(sqrt(${sorting_var})*sqrt(${causal_var}))	
		
		* store results in the czvar matrix
		clear
		svmat2 czvar_p`p', rnames(variables)
		gen number = [_n]
		rename czvar_p`p'1 cz_se_kr26_p`p'
		order number variables 
		tempfile czvar_kr26_p`p'_tc`scale_factor'
		save `czvar_kr26_p`p'_tc`scale_factor''
		}
		
		* organizing the commuting zones part:
		use `czvar_kr26_p25_tc`scale_factor'', clear
		merge 1:1 number using `czvar_kr26_p75_tc`scale_factor'', nogen
		tempfile czvar_full_tc`scale_factor'
		sa `czvar_full_tc`scale_factor''
		}
		
	* B County Level 

	* Population Restrictions
	macro drop cz_pop_cutoff cty_pop_cutoff
	global cz_pop_cutoff 25000
	global cty_pop_cutoff 10000
	
		foreach scale_factor in 20 23 12{

		foreach p in 25 75 {
		
		* Define matrix to store the results
		mat define ctyvar_p`p'=J(4,1,.)
		matrix rownames ctyvar_p`p'= ${namelist}
		
		* Use County level dataset
		use ${data}/Online_data_table4.dta, clear

		* Merge with CZ level estimates from Online Data Table 3
		merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p*_czkr26 causal_p*_czkr26_am causal_p*_czkr26_bm causal_p*_czkr26_bs_se causal_p*_czkr26_am_se causal_p*_czkr26_bm_se) nogen

		* compute CZ plus CTY estimates and variance
		g causal_p`p'_czct_kr26_bs_se = sqrt(causal_p`p'_cty_kr26_se^2+(causal_p`p'_czkr26_bs_se^2))
		replace causal_p`p'_czct_kr26_bs_se = causal_p`p'_czkr26_bs_se if causal_p`p'_czct_kr26_bs_se ==. & causal_p`p'_cz_cty_kr26~=.
		rename causal_p`p'_cz_cty_kr26 causal_p`p'_czct_kr26
	
		*Drop all obs with missing values of permanent residents, which are necessary for predictions
		keep if perm_res_p`p'_kr26~=.
		
		*Generate variances and precision weights
		g causal_var_p`p'_czctkr26_bs = causal_p`p'_czct_kr26_bs_se ^2
		g precwt = 1/causal_var_p`p'_czctkr26_bs
		
		* estimate noise variances 
		qui sum causal_var_p`p'_czctkr26_bs [w=precwt]
		global noisevar = r(mean)
		
		*Calculate total variance
		su causal_p`p'_czct_kr26 [w=precwt], d
		global totvar=r(Var)

		global sigvar = $totvar-$noisevar
		assert ${sigvar}>0
		global sigsd = sqrt($sigvar)
			
		*Estimates of causal and sorting effects
		g causal_p`p' = `scale_factor'*causal_p`p'_czct_kr26
		g sorting_p`p' = perm_res_p`p'_kr26-causal_p`p'
		
		*Variance decomposition
		sum perm_res_p`p'_kr26 [w=precwt]
		global stayers_var = r(Var)
		
		*Signal variance of causal effects
		global causal_var = (`scale_factor'*${sigsd})^2	
		
		*Covariance of causal effects and sorting
		reg causal_p`p' perm_res_p`p'_kr26 [w=precwt]
		global covar_causal_sorting = _b[perm_res_p`p'_kr26]*${stayers_var}-${causal_var}
		global sorting_var = ${stayers_var}-${causal_var}-2*${covar_causal_sorting}

		* store the results
		mat def ctyvar_p`p'[1,1] = sqrt(${causal_var})
		mat def ctyvar_p`p'[2,1] = sqrt(${stayers_var})
		mat def ctyvar_p`p'[3,1] = sqrt($sorting_var)
		mat def ctyvar_p`p'[4,1] = ${covar_causal_sorting}/(sqrt(${sorting_var})*sqrt(${causal_var}))	
		
		clear
		svmat2 ctyvar_p`p', rnames(variables)
		gen number = [_n]
		rename ctyvar_p`p'1 cty_se_kr26_p`p'
		order number variables 
		tempfile ctyvar_kr26_p`p'_tc`scale_factor'
		save `ctyvar_kr26_p`p'_tc`scale_factor''
		}
		
		* organizing the county part:
		use `ctyvar_kr26_p25_tc`scale_factor'', clear
		merge 1:1 number using `ctyvar_kr26_p75_tc`scale_factor'', nogen
		tempfile ctyvar_full_tc`scale_factor'
		sa `ctyvar_full_tc`scale_factor''
		}
		
		foreach scale_factor in 20 23 12{
		use `czvar_full_tc`scale_factor'', clear
		merge 1:1 number using `ctyvar_full_tc`scale_factor'', nogen
		tempfile tc_`scale_factor'
		save `tc_`scale_factor''
		}
		
		use `tc_20', clear
		append using `tc_23'
		append using `tc_12'

		
	* C. Counties within CZ 
		
	* generate county within CZ results
	global name1 Causal_Effect_(SD_of_Signal) Permanent_Residents_(SD) ///
	Sorting_Component_(SD) 
	
	foreach p in 25 75 {
	gen cty_cz_se_kr26_p`p'=.
	drop number 
	gen number = _n
	
	* rows 1-2-3-5-6-7-9-10-11
	foreach name of global name1 {
	replace cty_cz_se_kr26_p`p' = sqrt(cty_se_kr26_p`p'^2 -cz_se_kr26_p`p'^2) if variables=="`name'"
	}
	* row 4
	sum cty_cz_se_kr26_p`p' if variables=="Causal_Effect_(SD_of_Signal)" & number==1
	global causal_p`p' = r(mean)
	sum cty_cz_se_kr26_p`p' if variables=="Permanent_Residents_(SD)" & number==2
	global perm_res_p`p' = r(mean)
	sum cty_cz_se_kr26_p`p' if variables=="Sorting_Component_(SD)" & number==3
	global sort_comp_p`p' = r(mean)
	replace cty_cz_se_kr26_p`p' = (${perm_res_p`p'}^2 - ${sort_comp_p`p'}^2 - ${causal_p`p'}^2)/(2*${sort_comp_p`p'}*${causal_p`p'}) if variables=="Corr_Sorting_Causal" & number==4
	* row 8
	sum cty_cz_se_kr26_p`p' if variables=="Causal_Effect_(SD_of_Signal)" & number==5
	global causal_p`p' = r(mean)
	sum cty_cz_se_kr26_p`p' if variables=="Permanent_Residents_(SD)" & number==6
	global perm_res_p`p' = r(mean)
	sum cty_cz_se_kr26_p`p' if variables=="Sorting_Component_(SD)" & number==7
	global sort_comp_p`p' = r(mean)
	replace cty_cz_se_kr26_p`p' = (${perm_res_p`p'}^2 - ${sort_comp_p`p'}^2 - ${causal_p`p'}^2)/(2*${sort_comp_p`p'}*${causal_p`p'}) if variables=="Corr_Sorting_Causal" & number==8
	* row 12
	sum cty_cz_se_kr26_p`p' if variables=="Causal_Effect_(SD_of_Signal)" & number==9
	global causal_p`p' = r(mean)
	sum cty_cz_se_kr26_p`p' if variables=="Permanent_Residents_(SD)" & number==10
	global perm_res_p`p' = r(mean)
	sum cty_cz_se_kr26_p`p' if variables=="Sorting_Component_(SD)" & number==11
	global sort_comp_p`p' = r(mean)
	replace cty_cz_se_kr26_p`p' = (${perm_res_p`p'}^2 - ${sort_comp_p`p'}^2 - ${causal_p`p'}^2)/(2*${sort_comp_p`p'}*${causal_p`p'}) if variables=="Corr_Sorting_Causal" & number==12
	}
	drop number
		
	outsheet using "${tables}/AppendixTableVII.csv",comma replace	
	
	
* APPENDIX TABLE 8: Predicted Place Effects for 50 Largest CZs for Below-Median Income Parents (p25) Individual Income 

	use ${data}/Online_data_table1.dta, clear
	keep pop2000 czname stateabbrv  *p25_kir26_m *p25_kir26_f *p25_kir26 *p25_kir26_avg
	order pop2000 czname stateabbrv *p25_kir26_m *p25_kir26_f *p25_kir26 *p25_kir26_avg
	drop dollar*
	gsort -pop2000
	keep in 1/50
	drop pop2000
	gsort -forecasts_p25_kir26_avg
	outsheet using "${tables}/AppendixTableVIII.csv",comma replace

* APPENDIX TABLE 9: Predicted Place Effects for 100 Largest Counties (Top and Bottom 25 Based on Individual Income Rank) 

	use ${data}/Online_data_table2.dta, clear
	gsort -cty_pop2000
	g pop_rank = _n
	keep if pop_rank<=100
	gsort -forecasts_p25_kir26_avg
	gen effect_rank = _n
	keep if effect_rank <= 25 | effect_rank >= 75
	keep county_name stateabbrv  *p25_kir26_m *p25_kir26_f *p25_kir26 *p25_kir26_avg
	order county_name stateabbrv  *p25_kir26_m *p25_kir26_f *p25_kir26 *p25_kir26_avg
	drop dollar*
	outsheet using "${tables}/AppendixTableIX.csv",comma replace
	
* APPENDIX TABLE 10: Regressions of Place Effects for Males Across Commuting Zones on Selected Covariates (Below-Median Income Parents (p25)) 
	
	* Define Selected Covariates
	global varlist cs_race_bla poor_share cs_race_theil_2000 cs00_seg_inc cs00_seg_inc_pov25 cs00_seg_inc_aff75 frac_traveltime_lt15 log_pop_density ///
	hhinc00 gini inc_share_1perc gini99 frac_middleclass ///
	taxrate subcty_total_taxes_pc subcty_total_expenditure_pc eitc_exposure tax_st_diff_top20 ///
	ccd_exp_tot ccd_pup_tch_ratio score_r dropout_r ///
	num_inst_pc tuition gradrate_r ///
	cs_labforce cs_elf_ind_man d_tradeusch_pw_1990 frac_worked1416 ///
	mig_inflow mig_outflow cs_born_foreign ///
	scap_ski90pcm rel_tot crime_violent ///
	cs_fam_wkidsinglemom cs_divorced cs_married ///
	median_house_value median_rent
	
	* define scale factor (baseline is 20 years of exposure)
	global scale_factor =20
	
	* use beta dataset
	use ${data}/Online_data_table3.dta, clear
	
	* define matrix to store results 
	mat define reg=J(40,9,.)
	local row =1
	matrix rownames reg= ${varlist}
	
	*Drop all obs with missing values of stayers, which are necessary for decomposition into sorting and causal
	keep if perm_res_p25_kr26_m~=.
	
	*Estimates of causal and sorting effects
	g causal = ${scale_factor}*causal_p25_czkr26_m
	g sorting = perm_res_p25_kr26_m-causal

	*Generate variances and precision weights
	g causal_var_p25_czkr26_m_bs = causal_p25_czkr26_m_se^2
	g precwt = 1/causal_var_p25_czkr26_m_bs
	
	* estimate signal and noise variances 
	qui sum causal_var_p25_czkr26_m_bs [w=precwt]
	global noisevar = r(mean)
	qui sum causal_p25_czkr26_m [w=precwt],d
	global totvar = r(Var)

	global sigvar = $totvar-$noisevar
	assert ${sigvar}>0
	global sigsd = sqrt($sigvar)
	
	* Regressions with Observables
	foreach var of global varlist {
	sum `var' [w=pop2000]
	global st_dev = r(sd)
	mat def reg[`row',1] = ${st_dev}
	
	qui reg causal_p25_czkr26_m `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',2] = _b[`var'_st]/${sigsd}
	mat def reg[`row',3] = _se[`var'_st]/${sigsd}
	
	qui reg perm_res_p25_kr26_m `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',4] = _b[`var'_st]
	mat def reg[`row',5] = _se[`var'_st]
	
	qui reg causal `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',6] = _b[`var'_st]
	mat def reg[`row',7] = _se[`var'_st]
	
	qui reg sorting `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',8] = _b[`var'_st]
	mat def reg[`row',9] = _se[`var'_st]
	local row = `row'+1
	}
	
	* store results in a matrix
	clear
	svmat2 reg, rnames(variables)
	gen number = [_n]
	rename reg1 std_dev_kr26_m_p25
	rename reg2 coef_corr_kr26_m_p25
	rename reg3 se_corr_kr26_m_p25
	rename reg4 coef_stayers_kr26_m_p25
	rename reg5 se_stayers_kr26_m_p25
	rename reg6 coef_causal_kr26_m_p25
	rename reg7 se_causal_kr26_m_p25
	rename reg8 coef_sorting_kr26_m_p25
	rename reg9 se_sorting_kr26_m_p25
	order number variables std* coef_corr* se_corr* coef_stayers* se_stayers* coef_causal* se_causal* coef_sorting* se_sorting*
	drop number
	
	outsheet using "${tables}/AppendixTableX.csv",comma replace
	
	
* APPENDIX TABLE 11: Regressions of Place Effects for Males Across Counties within Commuting Zones on Selected Covariates (Above-Median Income Parents (p75)) 

	* Define Selected Covariates
	global varlist cs_race_bla poor_share cs_race_theil_2000 cs00_seg_inc cs00_seg_inc_pov25 cs00_seg_inc_aff75 frac_traveltime_lt15 log_pop_density ///
	hhinc00 gini inc_share_1perc gini99 frac_middleclass ///
	taxrate subcty_total_taxes_pc subcty_total_expenditure_pc eitc_exposure tax_st_diff_top20 ///
	ccd_exp_tot ccd_pup_tch_ratio score_r dropout_r ///
	num_inst_pc tuition gradrate_r ///
	cs_labforce cs_elf_ind_man frac_worked1416 ///
	mig_inflow mig_outflow cs_born_foreign ///
	scap_ski90pcm rel_tot crime_violent ///
	cs_fam_wkidsinglemom cs_divorced cs_married ///
	median_house_value median_rent 
	
	* define scale factor (baseline is 20 years of exposure)
	global scale_factor =20
	
	* define matrix to store results 
	mat define reg=J(39,9,.)
	local row =1
	matrix rownames reg= ${varlist}
	
	* Save Signal Variance at the CZ level 
	
		* use beta dataset
		use ${data}/Online_data_table3.dta, clear
		
		*Drop all obs with missing values of stayers, which are necessary for decomposition into sorting and causal
		keep if perm_res_p25_kr26_m~=.

		*Generate variances and precision weights
		g causal_var_p25_czkr26_m_bs = causal_p25_czkr26_m_se^2
		g precwt = 1/causal_var_p25_czkr26_m_bs
		
		* estimate signal and noise variances 
		qui sum causal_var_p25_czkr26_m_bs [w=precwt]
		global noisevar_cz = r(mean)
		qui sum causal_p25_czkr26_m [w=precwt],d
		global totvar_cz = r(Var)

		global sigvar_cz = $totvar_cz-$noisevar_cz

	* County within CZ regressions 
	
		* Define Population cutoffs
		macro drop cz_pop_cutoff cty_pop_cutoff
		global cz_pop_cutoff 25000
		global cty_pop_cutoff 10000
		
		* use beta dataset
		use ${data}/Online_data_table4.dta, clear
	
		* Merge with CZ level estimates from Online Data Table 3
		merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p25_czkr26_m causal_p25_czkr26_m_se) nogen
		gen causal_p25_czkr26_m_bs_se = causal_p25_czkr26_m_se

		* compute CZ plus CTY estimates and variance
		g causal_p25_czct_kr26_m_bs_se = sqrt(causal_p25_cty_kr26_m_se^2+(causal_p25_czkr26_m_bs_se^2))
		replace causal_p25_czct_kr26_m_bs_se = causal_p25_czkr26_m_bs_se if causal_p25_czct_kr26_m_bs_se ==. & causal_p25_cz_cty_kr26_m~=.
		rename causal_p25_cz_cty_kr26_m causal_p25_czct_kr26_m
	
		*Drop all obs with missing values of permanent residents, which are necessary for predictions
		keep if perm_res_p25_kr26_m~=.
		
		*Generate variances and precision weights
		g causal_var_p25_czctkr26_m_bs = causal_p25_czct_kr26_m_bs_se ^2
		g precwt = 1/causal_var_p25_czctkr26_m_bs
		
		* estimate signal and noise variances 
		qui sum causal_var_p25_czctkr26_m_bs [w=precwt]
		global noisevar = r(mean)
		qui sum causal_p25_czct_kr26_m [w=precwt],d
		global totvar = r(Var)

		global sigvar = $totvar-$noisevar
		
		* Estimating signal SD of county within cz
		global sigsd_within = sqrt(${sigvar} - ${sigvar_cz})
	
		*Estimates of causal and sorting effects
		g causal = ${scale_factor}*causal_p25_czct_kr26_m
		g sorting = perm_res_p25_kr26_m - causal
	
	* Regressions with Observables
	
		foreach var of global varlist {
		sum `var' [w=cty_pop2000]
		global st_dev = r(sd)
		mat def reg[`row',1] = ${st_dev}
		
		qui areg causal_p25_czct_kr26_m `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',2] = _b[`var'_st]/${sigsd_within}
		mat def reg[`row',3] = _se[`var'_st]/${sigsd_within}
		
		qui areg perm_res_p25_kr26_m `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',4] = _b[`var'_st]
		mat def reg[`row',5] = _se[`var'_st]
		
		qui areg causal `var'_st [w=cty_pop2000],  absorb(cz) cluster(cz)
		mat def reg[`row',6] = _b[`var'_st]
		mat def reg[`row',7] = _se[`var'_st]
		
		qui areg sorting `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',8] = _b[`var'_st]
		mat def reg[`row',9] = _se[`var'_st]
		local row = `row'+1
		}
	
	* store results in a matrix
		clear
		svmat2 reg, rnames(variables)
		gen number = [_n]
		rename reg1 std_dev_kr26_m_p25
		rename reg2 coef_corr_kr26_m_p25
		rename reg3 se_corr_kr26_m_p25
		rename reg4 coef_stayers_kr26_m_p25
		rename reg5 se_stayers_kr26_m_p25
		rename reg6 coef_causal_kr26_m_p25
		rename reg7 se_causal_kr26_m_p25
		rename reg8 coef_sorting_kr26_m_p25
		rename reg9 se_sorting_kr26_m_p25
		order number variables std* coef_corr* se_corr* coef_stayers* se_stayers* coef_causal* se_causal* coef_sorting* se_sorting*
		drop number
	
	outsheet using "${tables}/AppendixTableXI.csv",comma replace
	
	
* APPENDIX TABLE 12: Regressions of Place Effects for Females Across Commuting Zones on Selected Covariates (Below-Median Income Parents (p25)) 
	
	* Define Selected Covariates
	global varlist cs_race_bla poor_share cs_race_theil_2000 cs00_seg_inc cs00_seg_inc_pov25 cs00_seg_inc_aff75 frac_traveltime_lt15 log_pop_density ///
	hhinc00 gini inc_share_1perc gini99 frac_middleclass ///
	taxrate subcty_total_taxes_pc subcty_total_expenditure_pc eitc_exposure tax_st_diff_top20 ///
	ccd_exp_tot ccd_pup_tch_ratio score_r dropout_r ///
	num_inst_pc tuition gradrate_r ///
	cs_labforce cs_elf_ind_man d_tradeusch_pw_1990 frac_worked1416 ///
	mig_inflow mig_outflow cs_born_foreign ///
	scap_ski90pcm rel_tot crime_violent ///
	cs_fam_wkidsinglemom cs_divorced cs_married ///
	median_house_value median_rent
	
	* define scale factor (baseline is 20 years of exposure)
	global scale_factor =20
	
	* use beta dataset
	use ${data}/Online_data_table3.dta, clear
	
	* define matrix to store results 
	mat define reg=J(40,9,.)
	local row =1
	matrix rownames reg= ${varlist}
	
	*Drop all obs with missing values of stayers, which are necessary for decomposition into sorting and causal
	keep if perm_res_p25_kr26_f~=.
	
	*Estimates of causal and sorting effects
	g causal = ${scale_factor}*causal_p25_czkr26_f
	g sorting = perm_res_p25_kr26_f-causal

	*Generate variances and precision weights
	g causal_var_p25_czkr26_f_bs = causal_p25_czkr26_f_se^2
	g precwt = 1/causal_var_p25_czkr26_f_bs
	
	* estimate signal and noise variances 
	qui sum causal_var_p25_czkr26_f_bs [w=precwt]
	global noisevar = r(mean)
	qui sum causal_p25_czkr26_f [w=precwt],d
	global totvar = r(Var)

	global sigvar = $totvar-$noisevar
	assert ${sigvar}>0
	global sigsd = sqrt($sigvar)
	
	* Regressions with Observables
	foreach var of global varlist {
	sum `var' [w=pop2000]
	global st_dev = r(sd)
	mat def reg[`row',1] = ${st_dev}
	
	qui reg causal_p25_czkr26_f `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',2] = _b[`var'_st]/${sigsd}
	mat def reg[`row',3] = _se[`var'_st]/${sigsd}
	
	qui reg perm_res_p25_kr26_f `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',4] = _b[`var'_st]
	mat def reg[`row',5] = _se[`var'_st]
	
	qui reg causal `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',6] = _b[`var'_st]
	mat def reg[`row',7] = _se[`var'_st]
	
	qui reg sorting `var'_st [w=pop2000], cluster(state_id)
	mat def reg[`row',8] = _b[`var'_st]
	mat def reg[`row',9] = _se[`var'_st]
	local row = `row'+1
	}
	
	* store results in a matrix
	clear
	svmat2 reg, rnames(variables)
	gen number = [_n]
	rename reg1 std_dev_kr26_f_p25
	rename reg2 coef_corr_kr26_f_p25
	rename reg3 se_corr_kr26_f_p25
	rename reg4 coef_stayers_kr26_f_p25
	rename reg5 se_stayers_kr26_f_p25
	rename reg6 coef_causal_kr26_f_p25
	rename reg7 se_causal_kr26_f_p25
	rename reg8 coef_sorting_kr26_f_p25
	rename reg9 se_sorting_kr26_f_p25
	order number variables std* coef_corr* se_corr* coef_stayers* se_stayers* coef_causal* se_causal* coef_sorting* se_sorting*
	drop number
	
	outsheet using "${tables}/AppendixTableXII.csv",comma replace

	* APPENDIX TABLE 13: Regressions of Place Effects for Females Across Counties within Commuting Zones on Selected Covariates (Above-Median Income Parents (p75)) 

	* Define Selected Covariates
	global varlist cs_race_bla poor_share cs_race_theil_2000 cs00_seg_inc cs00_seg_inc_pov25 cs00_seg_inc_aff75 frac_traveltime_lt15 log_pop_density ///
	hhinc00 gini inc_share_1perc gini99 frac_middleclass ///
	taxrate subcty_total_taxes_pc subcty_total_expenditure_pc eitc_exposure tax_st_diff_top20 ///
	ccd_exp_tot ccd_pup_tch_ratio score_r dropout_r ///
	num_inst_pc tuition gradrate_r ///
	cs_labforce cs_elf_ind_man frac_worked1416 ///
	mig_inflow mig_outflow cs_born_foreign ///
	scap_ski90pcm rel_tot crime_violent ///
	cs_fam_wkidsinglemom cs_divorced cs_married ///
	median_house_value median_rent 
	
	* define scale factor (baseline is 20 years of exposure)
	global scale_factor =20
	
	* define matrix to store results 
	mat define reg=J(39,9,.)
	local row =1
	matrix rownames reg= ${varlist}
	
	* Save Signal Variance at the CZ level 
	
		* use beta dataset
		use ${data}/Online_data_table3.dta, clear
		
		*Drop all obs with missing values of stayers, which are necessary for decomposition into sorting and causal
		keep if perm_res_p25_kr26_f~=.

		*Generate variances and precision weights
		g causal_var_p25_czkr26_f_bs = causal_p25_czkr26_f_se^2
		g precwt = 1/causal_var_p25_czkr26_f_bs
		
		* estimate signal and noise variances 
		qui sum causal_var_p25_czkr26_f_bs [w=precwt]
		global noisevar_cz = r(mean)
		qui sum causal_p25_czkr26_f [w=precwt],d
		global totvar_cz = r(Var)

		global sigvar_cz = $totvar_cz-$noisevar_cz

	* County within CZ regressions 
	
		* Define Population cutoffs
		macro drop cz_pop_cutoff cty_pop_cutoff
		global cz_pop_cutoff 25000
		global cty_pop_cutoff 10000
	
		* use beta dataset
		use ${data}/Online_data_table4.dta, clear
	
		* Merge with CZ level estimates from Online Data Table 3
		merge m:1 cz using ${data}/Online_data_table3, keepusing(causal_p25_czkr26_f causal_p25_czkr26_f_se) nogen
		gen causal_p25_czkr26_f_bs_se = causal_p25_czkr26_f_se

		* compute CZ plus CTY estimates and variance
		g causal_p25_czct_kr26_f_bs_se = sqrt(causal_p25_cty_kr26_f_se^2+(causal_p25_czkr26_f_bs_se^2))
		replace causal_p25_czct_kr26_f_bs_se = causal_p25_czkr26_f_bs_se if causal_p25_czct_kr26_f_bs_se ==. & causal_p25_cz_cty_kr26_f~=.
		rename causal_p25_cz_cty_kr26_f causal_p25_czct_kr26_f
	
		*Drop all obs with missing values of permanent residents, which are necessary for predictions
		keep if perm_res_p25_kr26_f~=.
		
		*Generate variances and precision weights
		g causal_var_p25_czctkr26_f_bs = causal_p25_czct_kr26_f_bs_se ^2
		g precwt = 1/causal_var_p25_czctkr26_f_bs
		
		* estimate signal and noise variances 
		qui sum causal_var_p25_czctkr26_f_bs [w=precwt]
		global noisevar = r(mean)
		qui sum causal_p25_czct_kr26_f [w=precwt],d
		global totvar = r(Var)

		global sigvar = $totvar-$noisevar
		
		* Estimating signal SD of county within cz
		global sigsd_within = sqrt(${sigvar} - ${sigvar_cz})
	
		*Estimates of causal and sorting effects
		g causal = ${scale_factor}*causal_p25_czct_kr26_f
		g sorting = perm_res_p25_kr26_f-causal
	
	* Regressions with Observables
	
		foreach var of global varlist {
		sum `var' [w=cty_pop2000]
		global st_dev = r(sd)
		mat def reg[`row',1] = ${st_dev}
		
		qui areg causal_p25_czct_kr26_f `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',2] = _b[`var'_st]/${sigsd_within}
		mat def reg[`row',3] = _se[`var'_st]/${sigsd_within}
		
		qui areg perm_res_p25_kr26_f `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',4] = _b[`var'_st]
		mat def reg[`row',5] = _se[`var'_st]
		
		qui areg causal `var'_st [w=cty_pop2000],  absorb(cz) cluster(cz)
		mat def reg[`row',6] = _b[`var'_st]
		mat def reg[`row',7] = _se[`var'_st]
		
		qui areg sorting `var'_st [w=cty_pop2000], absorb(cz) cluster(cz)
		mat def reg[`row',8] = _b[`var'_st]
		mat def reg[`row',9] = _se[`var'_st]
		local row = `row'+1
		}
	
	* store results in a matrix
		clear
		svmat2 reg, rnames(variables)
		gen number = [_n]
		rename reg1 std_dev_kr26_f_p25
		rename reg2 coef_corr_kr26_f_p25
		rename reg3 se_corr_kr26_f_p25
		rename reg4 coef_stayers_kr26_f_p25
		rename reg5 se_stayers_kr26_f_p25
		rename reg6 coef_causal_kr26_f_p25
		rename reg7 se_causal_kr26_f_p25
		rename reg8 coef_sorting_kr26_f_p25
		rename reg9 se_sorting_kr26_f_p25
		order number variables std* coef_corr* se_corr* coef_stayers* se_stayers* coef_causal* se_causal* coef_sorting* se_sorting*
		drop number
	
	outsheet using "${tables}/AppendixTableXIII.csv",comma replace
